/********************************************************************************
** Form generated from reading UI file 'optionsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONSDIALOG_H
#define UI_OPTIONSDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "gui/fspathedit.h"

QT_BEGIN_NAMESPACE

class Ui_OptionsDialog
{
public:
    QVBoxLayout *verticalLayout_3;
    QSplitter *hsplitter;
    QListWidget *tabSelection;
    QStackedWidget *tabOption;
    QWidget *tabBehaviorPage;
    QVBoxLayout *verticalLayout_10;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_9;
    QGroupBox *UISettingsBox;
    QVBoxLayout *UISettingsBoxLayout;
    QLabel *labelRestartRequired;
    QHBoxLayout *layoutLanguage;
    QLabel *labelLanguage;
    QComboBox *comboLanguage;
    QSpacerItem *spacerLanguage;
    QGridLayout *layoutStyle;
    QLabel *labelStyle;
    QComboBox *comboStyle;
    QLabel *labelStyleHint;
    QLabel *labelColorScheme;
    QComboBox *comboColorScheme;
    QSpacerItem *spacerColorScheme;
    QGroupBox *checkUseCustomTheme;
    QHBoxLayout *horizontalLayout_18;
    QLabel *label_16;
    FileSystemPathLineEdit *customThemeFilePath;
    QCheckBox *checkUseSystemIcon;
    QPushButton *buttonCustomizeUITheme;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *confirmDeletion;
    QCheckBox *checkAltRowColors;
    QCheckBox *checkUseTorrentStatesColors;
    QCheckBox *checkProgressBarFollowsTextColor;
    QHBoxLayout *horizontalLayout;
    QCheckBox *checkHideZero;
    QComboBox *comboHideZero;
    QSpacerItem *horizontalSpacer_10;
    QGroupBox *groupBox_7;
    QGridLayout *gridLayout_14;
    QLabel *lblDlList_2;
    QComboBox *actionTorrentDlOnDblClBox;
    QSpacerItem *horizontalSpacer_12;
    QLabel *lblUploadList;
    QComboBox *actionTorrentFnOnDblClBox;
    QCheckBox *checkBoxHideZeroStatusFilters;
    QCheckBox *checkBoxUseSeparateTrackerStatusFilter;
    QGroupBox *boxTorrentContent;
    QVBoxLayout *layoutTorrentContent;
    QCheckBox *checkTorrentContentDrag;
    QGroupBox *systrayBox;
    QVBoxLayout *verticalLayout_12;
    QCheckBox *checkStartup;
    QCheckBox *checkShowSplash;
    QHBoxLayout *windowStateLayout;
    QLabel *windowStateLabel;
    QComboBox *windowStateComboBox;
    QSpacerItem *windowStateSpacer;
    QCheckBox *checkProgramExitConfirm;
    QCheckBox *checkProgramAutoExitConfirm;
    QGroupBox *checkShowSystray;
    QVBoxLayout *verticalLayout_22;
    QCheckBox *checkMinimizeToSysTray;
    QCheckBox *checkCloseToSystray;
    QHBoxLayout *horizontalLayout_4;
    QLabel *labelTrayIconStyle;
    QComboBox *comboTrayIcon;
    QSpacerItem *horizontalSpacer_13;
    QGroupBox *groupFileAssociation;
    QVBoxLayout *verticalLayout_28;
    QWidget *assocPanel;
    QVBoxLayout *assocPanelLayout;
    QCheckBox *checkAssociateTorrents;
    QCheckBox *checkAssociateMagnetLinks;
    QWidget *defaultProgramPanel;
    QVBoxLayout *defaultProgramPanelLayout;
    QLabel *labelSetAssoc;
    QCheckBox *checkProgramUpdates;
    QCheckBox *checkShowSpeedInDock;
    QCheckBox *checkShowMenuBarIcon;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_16;
    QCheckBox *checkPreventFromSuspendWhenDownloading;
    QCheckBox *checkPreventFromSuspendWhenSeeding;
    QGroupBox *checkFileLog;
    QVBoxLayout *verticalLayout_11;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_4;
    FileSystemPathLineEdit *textFileLogPath;
    QHBoxLayout *horizontalLayout_8;
    QCheckBox *checkFileLogBackup;
    QSpinBox *spinFileLogSize;
    QSpacerItem *horizontalSpacer_100;
    QHBoxLayout *horizontalLayout_9;
    QCheckBox *checkFileLogDelete;
    QSpinBox *spinFileLogAge;
    QComboBox *comboFileLogAgeType;
    QSpacerItem *horizontalSpacer_16;
    QCheckBox *checkBoxFreeDiskSpaceStatusBar;
    QCheckBox *checkBoxExternalIPStatusBar;
    QCheckBox *checkBoxPerformanceWarning;
    QSpacerItem *verticalSpacer_4;
    QWidget *tabDownloadsPage;
    QVBoxLayout *verticalLayout_13;
    QScrollArea *scrollArea_2;
    QWidget *scrollAreaWidgetContents_2;
    QVBoxLayout *verticalLayout;
    QGroupBox *torrentAdditionBox;
    QVBoxLayout *torrentAdditionBoxLayout;
    QGroupBox *checkAdditionDialog;
    QVBoxLayout *verticalLayout_18;
    QCheckBox *checkAdditionDialogFront;
    QHBoxLayout *horizontalLayout_19;
    QLabel *contentLayoutLabel;
    QComboBox *contentLayoutComboBox;
    QSpacerItem *horizontalSpacer_20;
    QCheckBox *checkAddToQueueTop;
    QCheckBox *checkAddStopped;
    QHBoxLayout *stopConditionLayout;
    QLabel *stopConditionLabel;
    QComboBox *stopConditionComboBox;
    QSpacerItem *stopConditionSpacer;
    QGroupBox *duplicateTorrentGroup;
    QVBoxLayout *duplicateTorrentBoxLayout;
    QCheckBox *checkMergeTrackers;
    QCheckBox *checkConfirmMergeTrackers;
    QGroupBox *deleteTorrentBox;
    QVBoxLayout *deleteTorrentBoxLayout;
    QCheckBox *deleteCancelledTorrentBox;
    QHBoxLayout *deleteTorrentWarningLayout;
    QLabel *deleteTorrentWarningIcon;
    QLabel *deleteTorrentWarningLabel;
    QCheckBox *checkPreallocateAll;
    QCheckBox *checkAppendqB;
    QCheckBox *checkUnwantedFolder;
    QCheckBox *checkRecursiveDownload;
    QGroupBox *groupSavingManagement;
    QVBoxLayout *groupSavingManagementLayout;
    QGridLayout *gridLayout_3;
    QLabel *label_40;
    QHBoxLayout *horizontalLayout_70;
    QComboBox *comboSavingMode;
    QSpacerItem *horizontalSpacer_160;
    QLabel *labelTorrentCategoryChanged;
    QHBoxLayout *horizontalLayout_14;
    QComboBox *comboTorrentCategoryChanged;
    QSpacerItem *horizontalSpacer_17;
    QLabel *labelCategoryDefaultPathChanged;
    QHBoxLayout *horizontalLayout_15;
    QComboBox *comboCategoryDefaultPathChanged;
    QSpacerItem *horizontalSpacer_18;
    QLabel *labelCategoryChanged;
    QHBoxLayout *horizontalLayout_17;
    QComboBox *comboCategoryChanged;
    QSpacerItem *horizontalSpacer_19;
    QCheckBox *checkUseCategoryPaths;
    QGridLayout *gridLayout_4;
    QLabel *labelSavePath;
    FileSystemPathLineEdit *textSavePath;
    QCheckBox *checkUseDownloadPath;
    FileSystemPathLineEdit *textDownloadPath;
    QCheckBox *checkExportDir;
    FileSystemPathLineEdit *textExportDir;
    QCheckBox *checkExportDirFin;
    FileSystemPathLineEdit *textExportDirFin;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_38;
    QHBoxLayout *horizontalLayout_16;
    QTreeView *scanFoldersView;
    QVBoxLayout *verticalLayout_37;
    QPushButton *addWatchedFolderButton;
    QPushButton *editWatchedFolderButton;
    QPushButton *removeWatchedFolderButton;
    QSpacerItem *verticalSpacer_6;
    QGroupBox *groupExcludedFileNames;
    QVBoxLayout *verticalLayout_311;
    QPlainTextEdit *textExcludedFileNames;
    QGroupBox *groupMailNotification;
    QVBoxLayout *verticalLayout_171;
    QGridLayout *gridLayout_9;
    QLabel *label_25;
    QLineEdit *senderEmailTxt;
    QLabel *label_2;
    QLineEdit *lineEditDestEmail;
    QLabel *label_3;
    QLineEdit *lineEditSmtpServer;
    QCheckBox *checkSmtpSSL;
    QGroupBox *groupMailNotifAuth;
    QFormLayout *formLayout_2;
    QLabel *label_7;
    QLineEdit *mailNotifUsername;
    QLabel *label_8;
    QLineEdit *mailNotifPassword;
    QPushButton *sendTestEmail;
    QGroupBox *autoRunBox;
    QVBoxLayout *verticalLayout_19;
    QGroupBox *groupBoxRunOnAdded;
    QVBoxLayout *verticalLayout_39;
    QLineEdit *lineEditRunOnAdded;
    QGroupBox *groupBoxRunOnFinished;
    QVBoxLayout *verticalLayout_36;
    QLineEdit *lineEditRunOnFinished;
    QCheckBox *autoRunConsole;
    QLabel *labelAutoRunParam;
    QWidget *tabConnectionPage;
    QVBoxLayout *verticalLayout_6;
    QScrollArea *scrollArea_3;
    QWidget *scrollAreaWidgetContents_3;
    QVBoxLayout *verticalLayout_20;
    QHBoxLayout *horizontalLayout_12;
    QLabel *label_24;
    QComboBox *comboProtocol;
    QSpacerItem *horizontalSpacer_23;
    QGroupBox *ListeningPortBox;
    QVBoxLayout *listeningPortLayout;
    QHBoxLayout *listeningPortLayout2;
    QLabel *lbl_ports;
    QSpinBox *spinPort;
    QPushButton *randomButton;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *checkUPnP;
    QGroupBox *nbConnecBox;
    QGridLayout *gridLayout;
    QCheckBox *checkMaxConnections;
    QSpinBox *spinMaxConnec;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *checkMaxConnectionsPerTorrent;
    QSpinBox *spinMaxConnecPerTorrent;
    QCheckBox *checkMaxUploads;
    QSpinBox *spinMaxUploads;
    QCheckBox *checkMaxUploadsPerTorrent;
    QSpinBox *spinMaxUploadsPerTorrent;
    QGroupBox *groupI2P;
    QVBoxLayout *verticalLayout_40;
    QHBoxLayout *i2pLayout;
    QLabel *labelI2PHost;
    QLineEdit *textI2PHost;
    QLabel *labelI2PPort;
    QSpinBox *spinI2PPort;
    QSpacerItem *horizontalSpacer_22;
    QCheckBox *checkI2PMixed;
    QGroupBox *groupProxy;
    QVBoxLayout *verticalLayout_29;
    QHBoxLayout *proxyTypeLayout;
    QLabel *ProxyType_lbl;
    QComboBox *comboProxyType;
    QLabel *lblProxyIP;
    QLineEdit *textProxyIP;
    QLabel *lblProxyPort;
    QSpinBox *spinProxyPort;
    QSpacerItem *horizontalSpacer_24;
    QLabel *labelProxyTypeUnavailable;
    QCheckBox *checkProxyHostnameLookup;
    QGroupBox *checkProxyAuth;
    QVBoxLayout *verticalLayout_24;
    QGridLayout *gridLayout_12;
    QLabel *lblProxyUsername;
    QLineEdit *textProxyUsername;
    QLabel *lblProxyPassword;
    QLineEdit *textProxyPassword;
    QLabel *label_23;
    QGroupBox *checkProxyBitTorrent;
    QVBoxLayout *verticalLayoutProxyBitTorrent;
    QCheckBox *checkProxyPeerConnections;
    QCheckBox *checkProxyRSS;
    QCheckBox *checkProxyMisc;
    QGroupBox *groupIPFilter;
    QVBoxLayout *verticalLayout_17;
    QHBoxLayout *horizontalLayout_11;
    QCheckBox *checkIPFilter;
    FileSystemPathLineEdit *textFilterPath;
    QToolButton *IpFilterRefreshBtn;
    QPushButton *banListButton;
    QCheckBox *checkIpFilterTrackers;
    QSpacerItem *verticalSpacer_3;
    QWidget *tabSpeedPage;
    QVBoxLayout *verticalLayout_34;
    QScrollArea *scrollArea_9;
    QWidget *scrollAreaWidgetContents_9;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *rateLimitBox;
    QGridLayout *rateLimitBoxLayout;
    QLabel *labelGlobalRate;
    QLabel *label_10;
    QSpinBox *spinUploadLimit;
    QSpacerItem *horizontalSpacer;
    QLabel *label_11;
    QSpinBox *spinDownloadLimit;
    QGroupBox *altRateLimitBox;
    QGridLayout *gridLayout_6;
    QLabel *labelAltRate;
    QLabel *label_13;
    QSpinBox *spinUploadLimitAlt;
    QSpacerItem *horizontalSpacer_5;
    QLabel *label_14;
    QSpinBox *spinDownloadLimitAlt;
    QGroupBox *groupBoxSchedule;
    QGridLayout *gridLayout_7;
    QLabel *label_6;
    QTimeEdit *timeEditScheduleFrom;
    QLabel *label_17;
    QTimeEdit *timeEditScheduleTo;
    QSpacerItem *horizontalSpacer_8;
    QLabel *label_18;
    QComboBox *comboBoxScheduleDays;
    QGroupBox *rateLimitsGroupBox;
    QVBoxLayout *verticalLayout_30;
    QCheckBox *checkLimituTPConnections;
    QCheckBox *checkLimitTransportOverhead;
    QCheckBox *checkLimitLocalPeerRate;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabBitTorrentPage;
    QVBoxLayout *verticalLayout_15;
    QScrollArea *scrollArea_4;
    QWidget *scrollAreaWidgetContents_4;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *AddBTFeaturesBox;
    QVBoxLayout *verticalLayout_14;
    QCheckBox *checkDHT;
    QCheckBox *checkPeX;
    QCheckBox *checkLSD;
    QHBoxLayout *hboxLayout;
    QLabel *lbl_encryption;
    QComboBox *comboEncryption;
    QSpacerItem *spacerItem;
    QHBoxLayout *horizontalLayout_6;
    QCheckBox *checkAnonymousMode;
    QLabel *label_anonymous;
    QSpacerItem *horizontalSpacer_14;
    QHBoxLayout *horizontalLayout_20;
    QLabel *labelMaxActiveCheckingTorrents;
    QSpinBox *spinBoxMaxActiveCheckingTorrents;
    QSpacerItem *horizontalSpacer_21;
    QGroupBox *checkEnableQueueing;
    QGridLayout *gridLayout_2;
    QLabel *label_max_active_dl;
    QSpinBox *spinMaxActiveDownloads;
    QSpacerItem *horizontalSpacer_7;
    QLabel *label_max_active_up;
    QSpinBox *spinMaxActiveUploads;
    QLabel *maxActiveTorrents_lbl;
    QSpinBox *spinMaxActiveTorrents;
    QGroupBox *checkIgnoreSlowTorrentsForQueueing;
    QGridLayout *gridLayout_13;
    QLabel *labelDownloadRateForSlowTorrents;
    QSpinBox *spinDownloadRateForSlowTorrents;
    QSpacerItem *horizontalSpacer_9;
    QLabel *labelUploadRateForSlowTorrents;
    QSpinBox *spinUploadRateForSlowTorrents;
    QLabel *labelSlowTorrentInactivityTimer;
    QSpinBox *spinSlowTorrentsInactivityTimer;
    QGroupBox *seedingLimitsBox;
    QGridLayout *gridLayout_15;
    QCheckBox *checkMaxRatio;
    QDoubleSpinBox *spinMaxRatio;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *checkMaxSeedingMinutes;
    QSpinBox *spinMaxSeedingMinutes;
    QCheckBox *checkMaxInactiveSeedingMinutes;
    QSpinBox *spinMaxInactiveSeedingMinutes;
    QLabel *label;
    QComboBox *comboRatioLimitAct;
    QGroupBox *checkEnableAddTrackers;
    QGridLayout *gridLayout_16;
    QPlainTextEdit *textTrackers;
    QGroupBox *checkAddTrackersFromURL;
    QVBoxLayout *checkAddTrackersFromURLLayout;
    QHBoxLayout *horizontalLayout_21;
    QLabel *labelCustomizeTrackersListUrl;
    QLineEdit *textTrackersURL;
    QLabel *labeltrackersFromURL;
    QPlainTextEdit *textTrackersFromURL;
    QSpacerItem *verticalSpacer_8;
    QWidget *tabSearchPage;
    QVBoxLayout *searchPageLayout;
    QScrollArea *searchPageScrollArea;
    QWidget *searchPageScrollAreaWidgetContents;
    QVBoxLayout *searchPageScrollAreaWidgetContentsLayout;
    QGroupBox *groupSearchUI;
    QVBoxLayout *groupSearchUILayout;
    QGroupBox *groupStoreOpenedTabs;
    QVBoxLayout *groupStoreOpenedTabsLayout;
    QCheckBox *checkStoreTabsSearchResults;
    QHBoxLayout *searchHistoryLayout;
    QLabel *searchHistoryLengthLabel;
    QSpinBox *searchHistoryLengthSpinBox;
    QSpacerItem *searchHistoryLengthSpacer;
    QSpacerItem *searchPageScrollAreaSpacer;
    QWidget *tabRSSPage;
    QVBoxLayout *verticalLayout_25;
    QScrollArea *scrollArea_5;
    QWidget *scrollAreaWidgetContents_5;
    QVBoxLayout *verticalLayout_27;
    QGroupBox *groupRSSReader;
    QVBoxLayout *verticalLayout_26;
    QCheckBox *checkRSSEnable;
    QGridLayout *gridLayout_5;
    QLabel *label_111;
    QSpinBox *spinRSSRefreshInterval;
    QSpacerItem *horizontalSpacer_6;
    QLabel *labelRSSFetchDelay;
    QSpinBox *spinRSSFetchDelay;
    QLabel *label_12;
    QSpinBox *spinRSSMaxArticlesPerFeed;
    QGroupBox *groupRSSAutoDownloader;
    QVBoxLayout *verticalLayout_21;
    QCheckBox *checkRSSAutoDownloaderEnable;
    QPushButton *btnEditRules;
    QGroupBox *groupRSSSmartEpisodeFilter;
    QVBoxLayout *verticalLayout_31;
    QCheckBox *checkSmartFilterDownloadRepacks;
    QLabel *label_5;
    QPlainTextEdit *textSmartEpisodeFilters;
    QSpacerItem *verticalSpacer_5;
    QWidget *tabWebUIPage;
    QVBoxLayout *tabWebUIPageLayout;
    QScrollArea *scrollArea_7;
    QWidget *scrollAreaWidgetContents_7;
    QVBoxLayout *verticalLayout_23;
    QGroupBox *checkWebUI;
    QVBoxLayout *verticalLayout_2;
    QLabel *labelWebUIError;
    QHBoxLayout *horizontalLayout_2;
    QLabel *lblWebUIAddress;
    QLineEdit *textWebUIAddress;
    QLabel *lblWebUIPort;
    QSpinBox *spinWebUIPort;
    QCheckBox *checkWebUIUPnP;
    QGroupBox *checkWebUIHttps;
    QGridLayout *gridLayout_11;
    QLabel *lblSslCertStatus;
    QLabel *lblWebUICrt;
    FileSystemPathLineEdit *textWebUIHttpsCert;
    QLabel *lblSslKeyStatus;
    QLabel *lblWebUIKey;
    FileSystemPathLineEdit *textWebUIHttpsKey;
    QLabel *lblWebUICertInfo;
    QGroupBox *groupWebUIAuth;
    QVBoxLayout *verticalLayout_35;
    QGroupBox *groupWebUIUser;
    QGridLayout *gridLayoutUser;
    QLabel *lblWebUIUsername;
    QLineEdit *textWebUIUsername;
    QLabel *lblWebUIPassword;
    QLineEdit *textWebUIPassword;
    QGroupBox *groupWebUIAPIKey;
    QGridLayout *gridLayoutAPIKey;
    QLabel *lblWebUIAPIKey;
    QHBoxLayout *horizontalLayoutAPIKey;
    QLineEdit *textWebUIAPIKey;
    QPushButton *btnWebUIAPIKeyCopy;
    QPushButton *btnWebUIAPIKeyRotate;
    QPushButton *btnWebUIAPIKeyDelete;
    QCheckBox *checkBypassLocalAuth;
    QCheckBox *checkBypassAuthSubnetWhitelist;
    QPushButton *IPSubnetWhitelistButton;
    QGridLayout *gridLayout_10;
    QLabel *lblBanCounter;
    QSpinBox *spinBanCounter;
    QSpacerItem *horizontalSpacer_15;
    QLabel *lblBanDuration;
    QSpinBox *spinBanDuration;
    QHBoxLayout *horizontalLayout_13;
    QLabel *lblSessionTimeout;
    QSpinBox *spinSessionTimeout;
    QSpacerItem *horizontalSpacer_11;
    QGroupBox *groupAltWebUI;
    QVBoxLayout *verticalLayout_41;
    QHBoxLayout *horizontalLayout_5;
    QLabel *labelWebUIRootFolder;
    FileSystemPathLineEdit *textWebUIRootFolder;
    QLabel *lblAltWebUIList;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_33;
    QCheckBox *checkClickjacking;
    QCheckBox *checkCSRFProtection;
    QCheckBox *checkSecureCookie;
    QGroupBox *groupHostHeaderValidation;
    QVBoxLayout *verticalLayout_32;
    QHBoxLayout *horizontalLayout_10;
    QLabel *labelServerDomains;
    QLineEdit *textServerDomains;
    QGroupBox *groupWebUIAddCustomHTTPHeaders;
    QVBoxLayout *verticalLayout_8;
    QPlainTextEdit *textWebUICustomHTTPHeaders;
    QGroupBox *groupEnableReverseProxySupport;
    QVBoxLayout *verticalLayout_331;
    QHBoxLayout *horizontalLayout_131;
    QLabel *lblReverseProxiesList;
    QLineEdit *textTrustedReverseProxiesList;
    QLabel *labelReverseProxyLink;
    QGroupBox *checkDynDNS;
    QFormLayout *formLayout_5;
    QLabel *label_19;
    QHBoxLayout *horizontalLayout_3;
    QComboBox *comboDNSService;
    QPushButton *registerDNSBtn;
    QLabel *label_20;
    QLineEdit *domainNameTxt;
    QLabel *label_21;
    QLineEdit *DNSUsernameTxt;
    QLabel *label_22;
    QLineEdit *DNSPasswordTxt;
    QSpacerItem *verticalSpacer;
    QWidget *tabAdvancedPage;
    QVBoxLayout *advPageLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *OptionsDialog)
    {
        if (OptionsDialog->objectName().isEmpty())
            OptionsDialog->setObjectName("OptionsDialog");
        OptionsDialog->resize(779, 591);
        verticalLayout_3 = new QVBoxLayout(OptionsDialog);
        verticalLayout_3->setObjectName("verticalLayout_3");
        hsplitter = new QSplitter(OptionsDialog);
        hsplitter->setObjectName("hsplitter");
        hsplitter->setOrientation(Qt::Orientation::Horizontal);
        hsplitter->setChildrenCollapsible(false);
        tabSelection = new QListWidget(hsplitter);
        new QListWidgetItem(tabSelection);
        new QListWidgetItem(tabSelection);
        new QListWidgetItem(tabSelection);
        new QListWidgetItem(tabSelection);
        new QListWidgetItem(tabSelection);
        new QListWidgetItem(tabSelection);
        new QListWidgetItem(tabSelection);
        new QListWidgetItem(tabSelection);
        new QListWidgetItem(tabSelection);
        tabSelection->setObjectName("tabSelection");
        tabSelection->setLayoutDirection(Qt::LayoutDirection::LeftToRight);
        tabSelection->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        tabSelection->setMovement(QListView::Movement::Static);
        tabSelection->setFlow(QListView::Flow::TopToBottom);
        tabSelection->setProperty("isWrapping", QVariant(false));
        tabSelection->setResizeMode(QListView::ResizeMode::Adjust);
        tabSelection->setViewMode(QListView::ViewMode::IconMode);
        hsplitter->addWidget(tabSelection);
        tabOption = new QStackedWidget(hsplitter);
        tabOption->setObjectName("tabOption");
        tabBehaviorPage = new QWidget();
        tabBehaviorPage->setObjectName("tabBehaviorPage");
        verticalLayout_10 = new QVBoxLayout(tabBehaviorPage);
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalLayout_10->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QScrollArea(tabBehaviorPage);
        scrollArea->setObjectName("scrollArea");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(scrollArea->sizePolicy().hasHeightForWidth());
        scrollArea->setSizePolicy(sizePolicy);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 504, 1064));
        verticalLayout_9 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_9->setObjectName("verticalLayout_9");
        UISettingsBox = new QGroupBox(scrollAreaWidgetContents);
        UISettingsBox->setObjectName("UISettingsBox");
        UISettingsBoxLayout = new QVBoxLayout(UISettingsBox);
        UISettingsBoxLayout->setObjectName("UISettingsBoxLayout");
        labelRestartRequired = new QLabel(UISettingsBox);
        labelRestartRequired->setObjectName("labelRestartRequired");
        QFont font;
        font.setItalic(true);
        labelRestartRequired->setFont(font);

        UISettingsBoxLayout->addWidget(labelRestartRequired);

        layoutLanguage = new QHBoxLayout();
        layoutLanguage->setObjectName("layoutLanguage");
        labelLanguage = new QLabel(UISettingsBox);
        labelLanguage->setObjectName("labelLanguage");

        layoutLanguage->addWidget(labelLanguage);

        comboLanguage = new QComboBox(UISettingsBox);
        comboLanguage->setObjectName("comboLanguage");

        layoutLanguage->addWidget(comboLanguage);

        spacerLanguage = new QSpacerItem(200, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layoutLanguage->addItem(spacerLanguage);


        UISettingsBoxLayout->addLayout(layoutLanguage);

        layoutStyle = new QGridLayout();
        layoutStyle->setObjectName("layoutStyle");
        labelStyle = new QLabel(UISettingsBox);
        labelStyle->setObjectName("labelStyle");

        layoutStyle->addWidget(labelStyle, 0, 0, 1, 1);

        comboStyle = new QComboBox(UISettingsBox);
        comboStyle->setObjectName("comboStyle");

        layoutStyle->addWidget(comboStyle, 0, 1, 1, 1);

        labelStyleHint = new QLabel(UISettingsBox);
        labelStyleHint->setObjectName("labelStyleHint");
        labelStyleHint->setFont(font);

        layoutStyle->addWidget(labelStyleHint, 0, 2, 1, 1);

        labelColorScheme = new QLabel(UISettingsBox);
        labelColorScheme->setObjectName("labelColorScheme");

        layoutStyle->addWidget(labelColorScheme, 1, 0, 1, 1);

        comboColorScheme = new QComboBox(UISettingsBox);
        comboColorScheme->setObjectName("comboColorScheme");

        layoutStyle->addWidget(comboColorScheme, 1, 1, 1, 1);

        spacerColorScheme = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layoutStyle->addItem(spacerColorScheme, 1, 2, 1, 1);


        UISettingsBoxLayout->addLayout(layoutStyle);

        checkUseCustomTheme = new QGroupBox(UISettingsBox);
        checkUseCustomTheme->setObjectName("checkUseCustomTheme");
        checkUseCustomTheme->setCheckable(true);
        horizontalLayout_18 = new QHBoxLayout(checkUseCustomTheme);
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        label_16 = new QLabel(checkUseCustomTheme);
        label_16->setObjectName("label_16");

        horizontalLayout_18->addWidget(label_16);

        customThemeFilePath = new FileSystemPathLineEdit(checkUseCustomTheme);
        customThemeFilePath->setObjectName("customThemeFilePath");

        horizontalLayout_18->addWidget(customThemeFilePath);


        UISettingsBoxLayout->addWidget(checkUseCustomTheme);

        checkUseSystemIcon = new QCheckBox(UISettingsBox);
        checkUseSystemIcon->setObjectName("checkUseSystemIcon");

        UISettingsBoxLayout->addWidget(checkUseSystemIcon);

        buttonCustomizeUITheme = new QPushButton(UISettingsBox);
        buttonCustomizeUITheme->setObjectName("buttonCustomizeUITheme");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(buttonCustomizeUITheme->sizePolicy().hasHeightForWidth());
        buttonCustomizeUITheme->setSizePolicy(sizePolicy1);

        UISettingsBoxLayout->addWidget(buttonCustomizeUITheme);


        verticalLayout_9->addWidget(UISettingsBox);

        groupBox_4 = new QGroupBox(scrollAreaWidgetContents);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_4 = new QVBoxLayout(groupBox_4);
        verticalLayout_4->setObjectName("verticalLayout_4");
        confirmDeletion = new QCheckBox(groupBox_4);
        confirmDeletion->setObjectName("confirmDeletion");
        confirmDeletion->setChecked(true);

        verticalLayout_4->addWidget(confirmDeletion);

        checkAltRowColors = new QCheckBox(groupBox_4);
        checkAltRowColors->setObjectName("checkAltRowColors");
        checkAltRowColors->setChecked(true);

        verticalLayout_4->addWidget(checkAltRowColors);

        checkUseTorrentStatesColors = new QCheckBox(groupBox_4);
        checkUseTorrentStatesColors->setObjectName("checkUseTorrentStatesColors");
        checkUseTorrentStatesColors->setChecked(true);

        verticalLayout_4->addWidget(checkUseTorrentStatesColors);

        checkProgressBarFollowsTextColor = new QCheckBox(groupBox_4);
        checkProgressBarFollowsTextColor->setObjectName("checkProgressBarFollowsTextColor");

        verticalLayout_4->addWidget(checkProgressBarFollowsTextColor);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        checkHideZero = new QCheckBox(groupBox_4);
        checkHideZero->setObjectName("checkHideZero");

        horizontalLayout->addWidget(checkHideZero);

        comboHideZero = new QComboBox(groupBox_4);
        comboHideZero->addItem(QString());
        comboHideZero->addItem(QString());
        comboHideZero->setObjectName("comboHideZero");

        horizontalLayout->addWidget(comboHideZero);

        horizontalSpacer_10 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_10);


        verticalLayout_4->addLayout(horizontalLayout);

        groupBox_7 = new QGroupBox(groupBox_4);
        groupBox_7->setObjectName("groupBox_7");
        gridLayout_14 = new QGridLayout(groupBox_7);
        gridLayout_14->setObjectName("gridLayout_14");
        lblDlList_2 = new QLabel(groupBox_7);
        lblDlList_2->setObjectName("lblDlList_2");

        gridLayout_14->addWidget(lblDlList_2, 0, 0, 1, 1);

        actionTorrentDlOnDblClBox = new QComboBox(groupBox_7);
        actionTorrentDlOnDblClBox->addItem(QString());
        actionTorrentDlOnDblClBox->addItem(QString());
        actionTorrentDlOnDblClBox->addItem(QString());
        actionTorrentDlOnDblClBox->addItem(QString());
        actionTorrentDlOnDblClBox->addItem(QString());
        actionTorrentDlOnDblClBox->setObjectName("actionTorrentDlOnDblClBox");

        gridLayout_14->addWidget(actionTorrentDlOnDblClBox, 0, 1, 1, 1);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_14->addItem(horizontalSpacer_12, 0, 2, 1, 1);

        lblUploadList = new QLabel(groupBox_7);
        lblUploadList->setObjectName("lblUploadList");

        gridLayout_14->addWidget(lblUploadList, 1, 0, 1, 1);

        actionTorrentFnOnDblClBox = new QComboBox(groupBox_7);
        actionTorrentFnOnDblClBox->addItem(QString());
        actionTorrentFnOnDblClBox->addItem(QString());
        actionTorrentFnOnDblClBox->addItem(QString());
        actionTorrentFnOnDblClBox->addItem(QString());
        actionTorrentFnOnDblClBox->addItem(QString());
        actionTorrentFnOnDblClBox->setObjectName("actionTorrentFnOnDblClBox");

        gridLayout_14->addWidget(actionTorrentFnOnDblClBox, 1, 1, 1, 1);


        verticalLayout_4->addWidget(groupBox_7);

        checkBoxHideZeroStatusFilters = new QCheckBox(groupBox_4);
        checkBoxHideZeroStatusFilters->setObjectName("checkBoxHideZeroStatusFilters");

        verticalLayout_4->addWidget(checkBoxHideZeroStatusFilters);

        checkBoxUseSeparateTrackerStatusFilter = new QCheckBox(groupBox_4);
        checkBoxUseSeparateTrackerStatusFilter->setObjectName("checkBoxUseSeparateTrackerStatusFilter");

        verticalLayout_4->addWidget(checkBoxUseSeparateTrackerStatusFilter);


        verticalLayout_9->addWidget(groupBox_4);

        boxTorrentContent = new QGroupBox(scrollAreaWidgetContents);
        boxTorrentContent->setObjectName("boxTorrentContent");
        layoutTorrentContent = new QVBoxLayout(boxTorrentContent);
        layoutTorrentContent->setObjectName("layoutTorrentContent");
        checkTorrentContentDrag = new QCheckBox(boxTorrentContent);
        checkTorrentContentDrag->setObjectName("checkTorrentContentDrag");

        layoutTorrentContent->addWidget(checkTorrentContentDrag);


        verticalLayout_9->addWidget(boxTorrentContent);

        systrayBox = new QGroupBox(scrollAreaWidgetContents);
        systrayBox->setObjectName("systrayBox");
        verticalLayout_12 = new QVBoxLayout(systrayBox);
        verticalLayout_12->setObjectName("verticalLayout_12");
        checkStartup = new QCheckBox(systrayBox);
        checkStartup->setObjectName("checkStartup");

        verticalLayout_12->addWidget(checkStartup);

        checkShowSplash = new QCheckBox(systrayBox);
        checkShowSplash->setObjectName("checkShowSplash");
        checkShowSplash->setChecked(true);

        verticalLayout_12->addWidget(checkShowSplash);

        windowStateLayout = new QHBoxLayout();
        windowStateLayout->setObjectName("windowStateLayout");
        windowStateLabel = new QLabel(systrayBox);
        windowStateLabel->setObjectName("windowStateLabel");

        windowStateLayout->addWidget(windowStateLabel);

        windowStateComboBox = new QComboBox(systrayBox);
        windowStateComboBox->setObjectName("windowStateComboBox");

        windowStateLayout->addWidget(windowStateComboBox);

        windowStateSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        windowStateLayout->addItem(windowStateSpacer);


        verticalLayout_12->addLayout(windowStateLayout);

        checkProgramExitConfirm = new QCheckBox(systrayBox);
        checkProgramExitConfirm->setObjectName("checkProgramExitConfirm");
        checkProgramExitConfirm->setChecked(true);

        verticalLayout_12->addWidget(checkProgramExitConfirm);

        checkProgramAutoExitConfirm = new QCheckBox(systrayBox);
        checkProgramAutoExitConfirm->setObjectName("checkProgramAutoExitConfirm");
        checkProgramAutoExitConfirm->setChecked(true);

        verticalLayout_12->addWidget(checkProgramAutoExitConfirm);

        checkShowSystray = new QGroupBox(systrayBox);
        checkShowSystray->setObjectName("checkShowSystray");
        checkShowSystray->setCheckable(true);
        verticalLayout_22 = new QVBoxLayout(checkShowSystray);
        verticalLayout_22->setObjectName("verticalLayout_22");
        checkMinimizeToSysTray = new QCheckBox(checkShowSystray);
        checkMinimizeToSysTray->setObjectName("checkMinimizeToSysTray");
        checkMinimizeToSysTray->setChecked(false);

        verticalLayout_22->addWidget(checkMinimizeToSysTray);

        checkCloseToSystray = new QCheckBox(checkShowSystray);
        checkCloseToSystray->setObjectName("checkCloseToSystray");

        verticalLayout_22->addWidget(checkCloseToSystray);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        labelTrayIconStyle = new QLabel(checkShowSystray);
        labelTrayIconStyle->setObjectName("labelTrayIconStyle");

        horizontalLayout_4->addWidget(labelTrayIconStyle);

        comboTrayIcon = new QComboBox(checkShowSystray);
        comboTrayIcon->addItem(QString());
        comboTrayIcon->addItem(QString());
        comboTrayIcon->addItem(QString());
        comboTrayIcon->setObjectName("comboTrayIcon");

        horizontalLayout_4->addWidget(comboTrayIcon);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_13);


        verticalLayout_22->addLayout(horizontalLayout_4);


        verticalLayout_12->addWidget(checkShowSystray);

        groupFileAssociation = new QGroupBox(systrayBox);
        groupFileAssociation->setObjectName("groupFileAssociation");
        verticalLayout_28 = new QVBoxLayout(groupFileAssociation);
        verticalLayout_28->setObjectName("verticalLayout_28");
        assocPanel = new QWidget(groupFileAssociation);
        assocPanel->setObjectName("assocPanel");
        assocPanelLayout = new QVBoxLayout(assocPanel);
        assocPanelLayout->setObjectName("assocPanelLayout");
        assocPanelLayout->setContentsMargins(0, 0, 0, 0);
        checkAssociateTorrents = new QCheckBox(assocPanel);
        checkAssociateTorrents->setObjectName("checkAssociateTorrents");

        assocPanelLayout->addWidget(checkAssociateTorrents);

        checkAssociateMagnetLinks = new QCheckBox(assocPanel);
        checkAssociateMagnetLinks->setObjectName("checkAssociateMagnetLinks");

        assocPanelLayout->addWidget(checkAssociateMagnetLinks);


        verticalLayout_28->addWidget(assocPanel);

        defaultProgramPanel = new QWidget(groupFileAssociation);
        defaultProgramPanel->setObjectName("defaultProgramPanel");
        defaultProgramPanelLayout = new QVBoxLayout(defaultProgramPanel);
        defaultProgramPanelLayout->setObjectName("defaultProgramPanelLayout");
        defaultProgramPanelLayout->setContentsMargins(0, 0, 0, 0);
        labelSetAssoc = new QLabel(defaultProgramPanel);
        labelSetAssoc->setObjectName("labelSetAssoc");

        defaultProgramPanelLayout->addWidget(labelSetAssoc);


        verticalLayout_28->addWidget(defaultProgramPanel);


        verticalLayout_12->addWidget(groupFileAssociation);

        checkProgramUpdates = new QCheckBox(systrayBox);
        checkProgramUpdates->setObjectName("checkProgramUpdates");

        verticalLayout_12->addWidget(checkProgramUpdates);

        checkShowSpeedInDock = new QCheckBox(systrayBox);
        checkShowSpeedInDock->setObjectName("checkShowSpeedInDock");

        verticalLayout_12->addWidget(checkShowSpeedInDock);

        checkShowMenuBarIcon = new QCheckBox(systrayBox);
        checkShowMenuBarIcon->setObjectName("checkShowMenuBarIcon");

        verticalLayout_12->addWidget(checkShowMenuBarIcon);


        verticalLayout_9->addWidget(systrayBox);

        groupBox = new QGroupBox(scrollAreaWidgetContents);
        groupBox->setObjectName("groupBox");
        verticalLayout_16 = new QVBoxLayout(groupBox);
        verticalLayout_16->setObjectName("verticalLayout_16");
        checkPreventFromSuspendWhenDownloading = new QCheckBox(groupBox);
        checkPreventFromSuspendWhenDownloading->setObjectName("checkPreventFromSuspendWhenDownloading");

        verticalLayout_16->addWidget(checkPreventFromSuspendWhenDownloading);

        checkPreventFromSuspendWhenSeeding = new QCheckBox(groupBox);
        checkPreventFromSuspendWhenSeeding->setObjectName("checkPreventFromSuspendWhenSeeding");

        verticalLayout_16->addWidget(checkPreventFromSuspendWhenSeeding);


        verticalLayout_9->addWidget(groupBox);

        checkFileLog = new QGroupBox(scrollAreaWidgetContents);
        checkFileLog->setObjectName("checkFileLog");
        checkFileLog->setCheckable(true);
        checkFileLog->setChecked(true);
        verticalLayout_11 = new QVBoxLayout(checkFileLog);
        verticalLayout_11->setObjectName("verticalLayout_11");
        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        label_4 = new QLabel(checkFileLog);
        label_4->setObjectName("label_4");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy2);

        horizontalLayout_7->addWidget(label_4);

        textFileLogPath = new FileSystemPathLineEdit(checkFileLog);
        textFileLogPath->setObjectName("textFileLogPath");

        horizontalLayout_7->addWidget(textFileLogPath);


        verticalLayout_11->addLayout(horizontalLayout_7);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        checkFileLogBackup = new QCheckBox(checkFileLog);
        checkFileLogBackup->setObjectName("checkFileLogBackup");

        horizontalLayout_8->addWidget(checkFileLogBackup);

        spinFileLogSize = new QSpinBox(checkFileLog);
        spinFileLogSize->setObjectName("spinFileLogSize");
        spinFileLogSize->setMinimum(1);
        spinFileLogSize->setMaximum(1024000);
        spinFileLogSize->setValue(65);

        horizontalLayout_8->addWidget(spinFileLogSize);

        horizontalSpacer_100 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_100);


        verticalLayout_11->addLayout(horizontalLayout_8);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        checkFileLogDelete = new QCheckBox(checkFileLog);
        checkFileLogDelete->setObjectName("checkFileLogDelete");

        horizontalLayout_9->addWidget(checkFileLogDelete);

        spinFileLogAge = new QSpinBox(checkFileLog);
        spinFileLogAge->setObjectName("spinFileLogAge");
        spinFileLogAge->setMinimum(1);
        spinFileLogAge->setMaximum(365);
        spinFileLogAge->setValue(6);

        horizontalLayout_9->addWidget(spinFileLogAge);

        comboFileLogAgeType = new QComboBox(checkFileLog);
        comboFileLogAgeType->addItem(QString());
        comboFileLogAgeType->addItem(QString());
        comboFileLogAgeType->addItem(QString());
        comboFileLogAgeType->setObjectName("comboFileLogAgeType");

        horizontalLayout_9->addWidget(comboFileLogAgeType);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_16);


        verticalLayout_11->addLayout(horizontalLayout_9);


        verticalLayout_9->addWidget(checkFileLog);

        checkBoxFreeDiskSpaceStatusBar = new QCheckBox(scrollAreaWidgetContents);
        checkBoxFreeDiskSpaceStatusBar->setObjectName("checkBoxFreeDiskSpaceStatusBar");

        verticalLayout_9->addWidget(checkBoxFreeDiskSpaceStatusBar);

        checkBoxExternalIPStatusBar = new QCheckBox(scrollAreaWidgetContents);
        checkBoxExternalIPStatusBar->setObjectName("checkBoxExternalIPStatusBar");

        verticalLayout_9->addWidget(checkBoxExternalIPStatusBar);

        checkBoxPerformanceWarning = new QCheckBox(scrollAreaWidgetContents);
        checkBoxPerformanceWarning->setObjectName("checkBoxPerformanceWarning");

        verticalLayout_9->addWidget(checkBoxPerformanceWarning);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_9->addItem(verticalSpacer_4);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_10->addWidget(scrollArea);

        tabOption->addWidget(tabBehaviorPage);
        tabDownloadsPage = new QWidget();
        tabDownloadsPage->setObjectName("tabDownloadsPage");
        verticalLayout_13 = new QVBoxLayout(tabDownloadsPage);
        verticalLayout_13->setObjectName("verticalLayout_13");
        verticalLayout_13->setContentsMargins(0, 0, 0, 0);
        scrollArea_2 = new QScrollArea(tabDownloadsPage);
        scrollArea_2->setObjectName("scrollArea_2");
        scrollArea_2->setWidgetResizable(true);
        scrollAreaWidgetContents_2 = new QWidget();
        scrollAreaWidgetContents_2->setObjectName("scrollAreaWidgetContents_2");
        scrollAreaWidgetContents_2->setGeometry(QRect(0, 0, 539, 1457));
        verticalLayout = new QVBoxLayout(scrollAreaWidgetContents_2);
        verticalLayout->setObjectName("verticalLayout");
        torrentAdditionBox = new QGroupBox(scrollAreaWidgetContents_2);
        torrentAdditionBox->setObjectName("torrentAdditionBox");
        torrentAdditionBoxLayout = new QVBoxLayout(torrentAdditionBox);
        torrentAdditionBoxLayout->setObjectName("torrentAdditionBoxLayout");
        checkAdditionDialog = new QGroupBox(torrentAdditionBox);
        checkAdditionDialog->setObjectName("checkAdditionDialog");
        checkAdditionDialog->setCheckable(true);
        verticalLayout_18 = new QVBoxLayout(checkAdditionDialog);
        verticalLayout_18->setObjectName("verticalLayout_18");
        checkAdditionDialogFront = new QCheckBox(checkAdditionDialog);
        checkAdditionDialogFront->setObjectName("checkAdditionDialogFront");
        checkAdditionDialogFront->setChecked(true);

        verticalLayout_18->addWidget(checkAdditionDialogFront);


        torrentAdditionBoxLayout->addWidget(checkAdditionDialog);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        contentLayoutLabel = new QLabel(torrentAdditionBox);
        contentLayoutLabel->setObjectName("contentLayoutLabel");

        horizontalLayout_19->addWidget(contentLayoutLabel);

        contentLayoutComboBox = new QComboBox(torrentAdditionBox);
        contentLayoutComboBox->addItem(QString());
        contentLayoutComboBox->addItem(QString());
        contentLayoutComboBox->addItem(QString());
        contentLayoutComboBox->setObjectName("contentLayoutComboBox");

        horizontalLayout_19->addWidget(contentLayoutComboBox);

        horizontalSpacer_20 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_19->addItem(horizontalSpacer_20);


        torrentAdditionBoxLayout->addLayout(horizontalLayout_19);

        checkAddToQueueTop = new QCheckBox(torrentAdditionBox);
        checkAddToQueueTop->setObjectName("checkAddToQueueTop");

        torrentAdditionBoxLayout->addWidget(checkAddToQueueTop);

        checkAddStopped = new QCheckBox(torrentAdditionBox);
        checkAddStopped->setObjectName("checkAddStopped");

        torrentAdditionBoxLayout->addWidget(checkAddStopped);

        stopConditionLayout = new QHBoxLayout();
        stopConditionLayout->setObjectName("stopConditionLayout");
        stopConditionLabel = new QLabel(torrentAdditionBox);
        stopConditionLabel->setObjectName("stopConditionLabel");

        stopConditionLayout->addWidget(stopConditionLabel);

        stopConditionComboBox = new QComboBox(torrentAdditionBox);
        stopConditionComboBox->addItem(QString());
        stopConditionComboBox->addItem(QString());
        stopConditionComboBox->addItem(QString());
        stopConditionComboBox->setObjectName("stopConditionComboBox");

        stopConditionLayout->addWidget(stopConditionComboBox);

        stopConditionSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        stopConditionLayout->addItem(stopConditionSpacer);


        torrentAdditionBoxLayout->addLayout(stopConditionLayout);

        duplicateTorrentGroup = new QGroupBox(torrentAdditionBox);
        duplicateTorrentGroup->setObjectName("duplicateTorrentGroup");
        duplicateTorrentBoxLayout = new QVBoxLayout(duplicateTorrentGroup);
        duplicateTorrentBoxLayout->setObjectName("duplicateTorrentBoxLayout");
        checkMergeTrackers = new QCheckBox(duplicateTorrentGroup);
        checkMergeTrackers->setObjectName("checkMergeTrackers");
        checkMergeTrackers->setChecked(false);

        duplicateTorrentBoxLayout->addWidget(checkMergeTrackers);

        checkConfirmMergeTrackers = new QCheckBox(duplicateTorrentGroup);
        checkConfirmMergeTrackers->setObjectName("checkConfirmMergeTrackers");
        checkConfirmMergeTrackers->setChecked(true);

        duplicateTorrentBoxLayout->addWidget(checkConfirmMergeTrackers);


        torrentAdditionBoxLayout->addWidget(duplicateTorrentGroup);

        deleteTorrentBox = new QGroupBox(torrentAdditionBox);
        deleteTorrentBox->setObjectName("deleteTorrentBox");
        deleteTorrentBox->setCheckable(true);
        deleteTorrentBox->setChecked(false);
        deleteTorrentBoxLayout = new QVBoxLayout(deleteTorrentBox);
        deleteTorrentBoxLayout->setObjectName("deleteTorrentBoxLayout");
        deleteCancelledTorrentBox = new QCheckBox(deleteTorrentBox);
        deleteCancelledTorrentBox->setObjectName("deleteCancelledTorrentBox");

        deleteTorrentBoxLayout->addWidget(deleteCancelledTorrentBox);

        deleteTorrentWarningLayout = new QHBoxLayout();
        deleteTorrentWarningLayout->setObjectName("deleteTorrentWarningLayout");
        deleteTorrentWarningIcon = new QLabel(deleteTorrentBox);
        deleteTorrentWarningIcon->setObjectName("deleteTorrentWarningIcon");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(deleteTorrentWarningIcon->sizePolicy().hasHeightForWidth());
        deleteTorrentWarningIcon->setSizePolicy(sizePolicy3);
        deleteTorrentWarningIcon->setText(QString::fromUtf8("<>"));

        deleteTorrentWarningLayout->addWidget(deleteTorrentWarningIcon);

        deleteTorrentWarningLabel = new QLabel(deleteTorrentBox);
        deleteTorrentWarningLabel->setObjectName("deleteTorrentWarningLabel");

        deleteTorrentWarningLayout->addWidget(deleteTorrentWarningLabel);


        deleteTorrentBoxLayout->addLayout(deleteTorrentWarningLayout);


        torrentAdditionBoxLayout->addWidget(deleteTorrentBox);


        verticalLayout->addWidget(torrentAdditionBox);

        checkPreallocateAll = new QCheckBox(scrollAreaWidgetContents_2);
        checkPreallocateAll->setObjectName("checkPreallocateAll");

        verticalLayout->addWidget(checkPreallocateAll);

        checkAppendqB = new QCheckBox(scrollAreaWidgetContents_2);
        checkAppendqB->setObjectName("checkAppendqB");

        verticalLayout->addWidget(checkAppendqB);

        checkUnwantedFolder = new QCheckBox(scrollAreaWidgetContents_2);
        checkUnwantedFolder->setObjectName("checkUnwantedFolder");

        verticalLayout->addWidget(checkUnwantedFolder);

        checkRecursiveDownload = new QCheckBox(scrollAreaWidgetContents_2);
        checkRecursiveDownload->setObjectName("checkRecursiveDownload");

        verticalLayout->addWidget(checkRecursiveDownload);

        groupSavingManagement = new QGroupBox(scrollAreaWidgetContents_2);
        groupSavingManagement->setObjectName("groupSavingManagement");
        groupSavingManagementLayout = new QVBoxLayout(groupSavingManagement);
        groupSavingManagementLayout->setObjectName("groupSavingManagementLayout");
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        label_40 = new QLabel(groupSavingManagement);
        label_40->setObjectName("label_40");

        gridLayout_3->addWidget(label_40, 0, 0, 1, 1);

        horizontalLayout_70 = new QHBoxLayout();
        horizontalLayout_70->setSpacing(10);
        horizontalLayout_70->setObjectName("horizontalLayout_70");
        comboSavingMode = new QComboBox(groupSavingManagement);
        comboSavingMode->addItem(QString());
        comboSavingMode->addItem(QString());
        comboSavingMode->setObjectName("comboSavingMode");

        horizontalLayout_70->addWidget(comboSavingMode);

        horizontalSpacer_160 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_70->addItem(horizontalSpacer_160);


        gridLayout_3->addLayout(horizontalLayout_70, 0, 1, 1, 1);

        labelTorrentCategoryChanged = new QLabel(groupSavingManagement);
        labelTorrentCategoryChanged->setObjectName("labelTorrentCategoryChanged");

        gridLayout_3->addWidget(labelTorrentCategoryChanged, 1, 0, 1, 1);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        comboTorrentCategoryChanged = new QComboBox(groupSavingManagement);
        comboTorrentCategoryChanged->addItem(QString());
        comboTorrentCategoryChanged->addItem(QString());
        comboTorrentCategoryChanged->setObjectName("comboTorrentCategoryChanged");

        horizontalLayout_14->addWidget(comboTorrentCategoryChanged);

        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_17);


        gridLayout_3->addLayout(horizontalLayout_14, 1, 1, 1, 1);

        labelCategoryDefaultPathChanged = new QLabel(groupSavingManagement);
        labelCategoryDefaultPathChanged->setObjectName("labelCategoryDefaultPathChanged");

        gridLayout_3->addWidget(labelCategoryDefaultPathChanged, 2, 0, 1, 1);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        comboCategoryDefaultPathChanged = new QComboBox(groupSavingManagement);
        comboCategoryDefaultPathChanged->addItem(QString());
        comboCategoryDefaultPathChanged->addItem(QString());
        comboCategoryDefaultPathChanged->setObjectName("comboCategoryDefaultPathChanged");

        horizontalLayout_15->addWidget(comboCategoryDefaultPathChanged);

        horizontalSpacer_18 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_18);


        gridLayout_3->addLayout(horizontalLayout_15, 2, 1, 1, 1);

        labelCategoryChanged = new QLabel(groupSavingManagement);
        labelCategoryChanged->setObjectName("labelCategoryChanged");

        gridLayout_3->addWidget(labelCategoryChanged, 3, 0, 1, 1);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        comboCategoryChanged = new QComboBox(groupSavingManagement);
        comboCategoryChanged->addItem(QString());
        comboCategoryChanged->addItem(QString());
        comboCategoryChanged->setObjectName("comboCategoryChanged");

        horizontalLayout_17->addWidget(comboCategoryChanged);

        horizontalSpacer_19 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_19);


        gridLayout_3->addLayout(horizontalLayout_17, 3, 1, 1, 1);


        groupSavingManagementLayout->addLayout(gridLayout_3);

        checkUseCategoryPaths = new QCheckBox(groupSavingManagement);
        checkUseCategoryPaths->setObjectName("checkUseCategoryPaths");

        groupSavingManagementLayout->addWidget(checkUseCategoryPaths);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        labelSavePath = new QLabel(groupSavingManagement);
        labelSavePath->setObjectName("labelSavePath");

        gridLayout_4->addWidget(labelSavePath, 0, 0, 1, 1);

        textSavePath = new FileSystemPathLineEdit(groupSavingManagement);
        textSavePath->setObjectName("textSavePath");

        gridLayout_4->addWidget(textSavePath, 0, 1, 1, 1);

        checkUseDownloadPath = new QCheckBox(groupSavingManagement);
        checkUseDownloadPath->setObjectName("checkUseDownloadPath");

        gridLayout_4->addWidget(checkUseDownloadPath, 1, 0, 1, 1);

        textDownloadPath = new FileSystemPathLineEdit(groupSavingManagement);
        textDownloadPath->setObjectName("textDownloadPath");

        gridLayout_4->addWidget(textDownloadPath, 1, 1, 1, 1);

        checkExportDir = new QCheckBox(groupSavingManagement);
        checkExportDir->setObjectName("checkExportDir");

        gridLayout_4->addWidget(checkExportDir, 2, 0, 1, 1);

        textExportDir = new FileSystemPathLineEdit(groupSavingManagement);
        textExportDir->setObjectName("textExportDir");

        gridLayout_4->addWidget(textExportDir, 2, 1, 1, 1);

        checkExportDirFin = new QCheckBox(groupSavingManagement);
        checkExportDirFin->setObjectName("checkExportDirFin");

        gridLayout_4->addWidget(checkExportDirFin, 3, 0, 1, 1);

        textExportDirFin = new FileSystemPathLineEdit(groupSavingManagement);
        textExportDirFin->setObjectName("textExportDirFin");

        gridLayout_4->addWidget(textExportDirFin, 3, 1, 1, 1);


        groupSavingManagementLayout->addLayout(gridLayout_4);


        verticalLayout->addWidget(groupSavingManagement);

        groupBox_2 = new QGroupBox(scrollAreaWidgetContents_2);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_38 = new QVBoxLayout(groupBox_2);
        verticalLayout_38->setObjectName("verticalLayout_38");
        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        scanFoldersView = new QTreeView(groupBox_2);
        scanFoldersView->setObjectName("scanFoldersView");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(1);
        sizePolicy4.setHeightForWidth(scanFoldersView->sizePolicy().hasHeightForWidth());
        scanFoldersView->setSizePolicy(sizePolicy4);
        scanFoldersView->setMinimumSize(QSize(250, 150));
        scanFoldersView->setEditTriggers(QAbstractItemView::EditTrigger::AllEditTriggers);
        scanFoldersView->setSelectionMode(QAbstractItemView::SelectionMode::SingleSelection);
        scanFoldersView->setSelectionBehavior(QAbstractItemView::SelectionBehavior::SelectRows);
        scanFoldersView->setTextElideMode(Qt::TextElideMode::ElideNone);
        scanFoldersView->setRootIsDecorated(false);
        scanFoldersView->header()->setDefaultSectionSize(80);
        scanFoldersView->header()->setStretchLastSection(false);

        horizontalLayout_16->addWidget(scanFoldersView);

        verticalLayout_37 = new QVBoxLayout();
        verticalLayout_37->setObjectName("verticalLayout_37");
        addWatchedFolderButton = new QPushButton(groupBox_2);
        addWatchedFolderButton->setObjectName("addWatchedFolderButton");

        verticalLayout_37->addWidget(addWatchedFolderButton);

        editWatchedFolderButton = new QPushButton(groupBox_2);
        editWatchedFolderButton->setObjectName("editWatchedFolderButton");
        editWatchedFolderButton->setEnabled(false);

        verticalLayout_37->addWidget(editWatchedFolderButton);

        removeWatchedFolderButton = new QPushButton(groupBox_2);
        removeWatchedFolderButton->setObjectName("removeWatchedFolderButton");
        removeWatchedFolderButton->setEnabled(false);

        verticalLayout_37->addWidget(removeWatchedFolderButton);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_37->addItem(verticalSpacer_6);


        horizontalLayout_16->addLayout(verticalLayout_37);


        verticalLayout_38->addLayout(horizontalLayout_16);


        verticalLayout->addWidget(groupBox_2);

        groupExcludedFileNames = new QGroupBox(scrollAreaWidgetContents_2);
        groupExcludedFileNames->setObjectName("groupExcludedFileNames");
        groupExcludedFileNames->setCheckable(true);
        groupExcludedFileNames->setChecked(false);
        verticalLayout_311 = new QVBoxLayout(groupExcludedFileNames);
        verticalLayout_311->setObjectName("verticalLayout_311");
        textExcludedFileNames = new QPlainTextEdit(groupExcludedFileNames);
        textExcludedFileNames->setObjectName("textExcludedFileNames");
        textExcludedFileNames->setTabChangesFocus(true);
        textExcludedFileNames->setLineWrapMode(QPlainTextEdit::LineWrapMode::NoWrap);

        verticalLayout_311->addWidget(textExcludedFileNames);


        verticalLayout->addWidget(groupExcludedFileNames);

        groupMailNotification = new QGroupBox(scrollAreaWidgetContents_2);
        groupMailNotification->setObjectName("groupMailNotification");
        groupMailNotification->setCheckable(true);
        groupMailNotification->setChecked(false);
        verticalLayout_171 = new QVBoxLayout(groupMailNotification);
        verticalLayout_171->setObjectName("verticalLayout_171");
        gridLayout_9 = new QGridLayout();
        gridLayout_9->setObjectName("gridLayout_9");
        label_25 = new QLabel(groupMailNotification);
        label_25->setObjectName("label_25");

        gridLayout_9->addWidget(label_25, 0, 0, 1, 1);

        senderEmailTxt = new QLineEdit(groupMailNotification);
        senderEmailTxt->setObjectName("senderEmailTxt");

        gridLayout_9->addWidget(senderEmailTxt, 0, 1, 1, 1);

        label_2 = new QLabel(groupMailNotification);
        label_2->setObjectName("label_2");

        gridLayout_9->addWidget(label_2, 1, 0, 1, 1);

        lineEditDestEmail = new QLineEdit(groupMailNotification);
        lineEditDestEmail->setObjectName("lineEditDestEmail");

        gridLayout_9->addWidget(lineEditDestEmail, 1, 1, 1, 1);

        label_3 = new QLabel(groupMailNotification);
        label_3->setObjectName("label_3");

        gridLayout_9->addWidget(label_3, 2, 0, 1, 1);

        lineEditSmtpServer = new QLineEdit(groupMailNotification);
        lineEditSmtpServer->setObjectName("lineEditSmtpServer");

        gridLayout_9->addWidget(lineEditSmtpServer, 2, 1, 1, 1);


        verticalLayout_171->addLayout(gridLayout_9);

        checkSmtpSSL = new QCheckBox(groupMailNotification);
        checkSmtpSSL->setObjectName("checkSmtpSSL");

        verticalLayout_171->addWidget(checkSmtpSSL);

        groupMailNotifAuth = new QGroupBox(groupMailNotification);
        groupMailNotifAuth->setObjectName("groupMailNotifAuth");
        groupMailNotifAuth->setCheckable(true);
        groupMailNotifAuth->setChecked(false);
        formLayout_2 = new QFormLayout(groupMailNotifAuth);
        formLayout_2->setObjectName("formLayout_2");
        label_7 = new QLabel(groupMailNotifAuth);
        label_7->setObjectName("label_7");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        mailNotifUsername = new QLineEdit(groupMailNotifAuth);
        mailNotifUsername->setObjectName("mailNotifUsername");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, mailNotifUsername);

        label_8 = new QLabel(groupMailNotifAuth);
        label_8->setObjectName("label_8");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_8);

        mailNotifPassword = new QLineEdit(groupMailNotifAuth);
        mailNotifPassword->setObjectName("mailNotifPassword");
        mailNotifPassword->setEchoMode(QLineEdit::EchoMode::Password);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, mailNotifPassword);


        verticalLayout_171->addWidget(groupMailNotifAuth);

        sendTestEmail = new QPushButton(groupMailNotification);
        sendTestEmail->setObjectName("sendTestEmail");
        sizePolicy1.setHeightForWidth(sendTestEmail->sizePolicy().hasHeightForWidth());
        sendTestEmail->setSizePolicy(sizePolicy1);

        verticalLayout_171->addWidget(sendTestEmail);


        verticalLayout->addWidget(groupMailNotification);

        autoRunBox = new QGroupBox(scrollAreaWidgetContents_2);
        autoRunBox->setObjectName("autoRunBox");
        verticalLayout_19 = new QVBoxLayout(autoRunBox);
        verticalLayout_19->setObjectName("verticalLayout_19");
        groupBoxRunOnAdded = new QGroupBox(autoRunBox);
        groupBoxRunOnAdded->setObjectName("groupBoxRunOnAdded");
        groupBoxRunOnAdded->setCheckable(true);
        groupBoxRunOnAdded->setChecked(false);
        verticalLayout_39 = new QVBoxLayout(groupBoxRunOnAdded);
        verticalLayout_39->setObjectName("verticalLayout_39");
        lineEditRunOnAdded = new QLineEdit(groupBoxRunOnAdded);
        lineEditRunOnAdded->setObjectName("lineEditRunOnAdded");

        verticalLayout_39->addWidget(lineEditRunOnAdded);


        verticalLayout_19->addWidget(groupBoxRunOnAdded);

        groupBoxRunOnFinished = new QGroupBox(autoRunBox);
        groupBoxRunOnFinished->setObjectName("groupBoxRunOnFinished");
        groupBoxRunOnFinished->setCheckable(true);
        groupBoxRunOnFinished->setChecked(false);
        verticalLayout_36 = new QVBoxLayout(groupBoxRunOnFinished);
        verticalLayout_36->setObjectName("verticalLayout_36");
        lineEditRunOnFinished = new QLineEdit(groupBoxRunOnFinished);
        lineEditRunOnFinished->setObjectName("lineEditRunOnFinished");

        verticalLayout_36->addWidget(lineEditRunOnFinished);


        verticalLayout_19->addWidget(groupBoxRunOnFinished);

        autoRunConsole = new QCheckBox(autoRunBox);
        autoRunConsole->setObjectName("autoRunConsole");

        verticalLayout_19->addWidget(autoRunConsole);

        labelAutoRunParam = new QLabel(autoRunBox);
        labelAutoRunParam->setObjectName("labelAutoRunParam");
        labelAutoRunParam->setWordWrap(true);

        verticalLayout_19->addWidget(labelAutoRunParam);


        verticalLayout->addWidget(autoRunBox);

        scrollArea_2->setWidget(scrollAreaWidgetContents_2);

        verticalLayout_13->addWidget(scrollArea_2);

        tabOption->addWidget(tabDownloadsPage);
        tabConnectionPage = new QWidget();
        tabConnectionPage->setObjectName("tabConnectionPage");
        verticalLayout_6 = new QVBoxLayout(tabConnectionPage);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(0, 0, 0, 0);
        scrollArea_3 = new QScrollArea(tabConnectionPage);
        scrollArea_3->setObjectName("scrollArea_3");
        scrollArea_3->setWidgetResizable(true);
        scrollAreaWidgetContents_3 = new QWidget();
        scrollAreaWidgetContents_3->setObjectName("scrollAreaWidgetContents_3");
        scrollAreaWidgetContents_3->setGeometry(QRect(0, 0, 504, 848));
        verticalLayout_20 = new QVBoxLayout(scrollAreaWidgetContents_3);
        verticalLayout_20->setObjectName("verticalLayout_20");
        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        label_24 = new QLabel(scrollAreaWidgetContents_3);
        label_24->setObjectName("label_24");

        horizontalLayout_12->addWidget(label_24);

        comboProtocol = new QComboBox(scrollAreaWidgetContents_3);
        comboProtocol->addItem(QString());
        comboProtocol->addItem(QString::fromUtf8("TCP"));
        comboProtocol->addItem(QString::fromUtf8("\316\274TP"));
        comboProtocol->setObjectName("comboProtocol");

        horizontalLayout_12->addWidget(comboProtocol);

        horizontalSpacer_23 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_23);


        verticalLayout_20->addLayout(horizontalLayout_12);

        ListeningPortBox = new QGroupBox(scrollAreaWidgetContents_3);
        ListeningPortBox->setObjectName("ListeningPortBox");
        listeningPortLayout = new QVBoxLayout(ListeningPortBox);
        listeningPortLayout->setObjectName("listeningPortLayout");
        listeningPortLayout2 = new QHBoxLayout();
        listeningPortLayout2->setObjectName("listeningPortLayout2");
        lbl_ports = new QLabel(ListeningPortBox);
        lbl_ports->setObjectName("lbl_ports");

        listeningPortLayout2->addWidget(lbl_ports);

        spinPort = new QSpinBox(ListeningPortBox);
        spinPort->setObjectName("spinPort");
        spinPort->setMaximum(65535);

        listeningPortLayout2->addWidget(spinPort);

        randomButton = new QPushButton(ListeningPortBox);
        randomButton->setObjectName("randomButton");

        listeningPortLayout2->addWidget(randomButton);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        listeningPortLayout2->addItem(horizontalSpacer_4);


        listeningPortLayout->addLayout(listeningPortLayout2);

        checkUPnP = new QCheckBox(ListeningPortBox);
        checkUPnP->setObjectName("checkUPnP");
        checkUPnP->setChecked(true);

        listeningPortLayout->addWidget(checkUPnP);


        verticalLayout_20->addWidget(ListeningPortBox);

        nbConnecBox = new QGroupBox(scrollAreaWidgetContents_3);
        nbConnecBox->setObjectName("nbConnecBox");
        gridLayout = new QGridLayout(nbConnecBox);
        gridLayout->setObjectName("gridLayout");
        checkMaxConnections = new QCheckBox(nbConnecBox);
        checkMaxConnections->setObjectName("checkMaxConnections");
        checkMaxConnections->setChecked(true);

        gridLayout->addWidget(checkMaxConnections, 0, 0, 1, 1);

        spinMaxConnec = new QSpinBox(nbConnecBox);
        spinMaxConnec->setObjectName("spinMaxConnec");
        spinMaxConnec->setEnabled(true);
        spinMaxConnec->setMinimum(2);
        spinMaxConnec->setMaximum(2147483647);
        spinMaxConnec->setValue(500);

        gridLayout->addWidget(spinMaxConnec, 0, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 0, 2, 1, 1);

        checkMaxConnectionsPerTorrent = new QCheckBox(nbConnecBox);
        checkMaxConnectionsPerTorrent->setObjectName("checkMaxConnectionsPerTorrent");
        checkMaxConnectionsPerTorrent->setChecked(true);

        gridLayout->addWidget(checkMaxConnectionsPerTorrent, 1, 0, 1, 1);

        spinMaxConnecPerTorrent = new QSpinBox(nbConnecBox);
        spinMaxConnecPerTorrent->setObjectName("spinMaxConnecPerTorrent");
        spinMaxConnecPerTorrent->setMinimum(2);
        spinMaxConnecPerTorrent->setMaximum(2147483647);
        spinMaxConnecPerTorrent->setValue(100);

        gridLayout->addWidget(spinMaxConnecPerTorrent, 1, 1, 1, 1);

        checkMaxUploads = new QCheckBox(nbConnecBox);
        checkMaxUploads->setObjectName("checkMaxUploads");

        gridLayout->addWidget(checkMaxUploads, 2, 0, 1, 1);

        spinMaxUploads = new QSpinBox(nbConnecBox);
        spinMaxUploads->setObjectName("spinMaxUploads");
        spinMaxUploads->setMaximum(2147483647);
        spinMaxUploads->setValue(8);

        gridLayout->addWidget(spinMaxUploads, 2, 1, 1, 1);

        checkMaxUploadsPerTorrent = new QCheckBox(nbConnecBox);
        checkMaxUploadsPerTorrent->setObjectName("checkMaxUploadsPerTorrent");

        gridLayout->addWidget(checkMaxUploadsPerTorrent, 3, 0, 1, 1);

        spinMaxUploadsPerTorrent = new QSpinBox(nbConnecBox);
        spinMaxUploadsPerTorrent->setObjectName("spinMaxUploadsPerTorrent");
        spinMaxUploadsPerTorrent->setMaximum(2147483647);
        spinMaxUploadsPerTorrent->setValue(4);

        gridLayout->addWidget(spinMaxUploadsPerTorrent, 3, 1, 1, 1);


        verticalLayout_20->addWidget(nbConnecBox);

        groupI2P = new QGroupBox(scrollAreaWidgetContents_3);
        groupI2P->setObjectName("groupI2P");
        groupI2P->setCheckable(true);
        groupI2P->setChecked(true);
        verticalLayout_40 = new QVBoxLayout(groupI2P);
        verticalLayout_40->setObjectName("verticalLayout_40");
        i2pLayout = new QHBoxLayout();
        i2pLayout->setObjectName("i2pLayout");
        labelI2PHost = new QLabel(groupI2P);
        labelI2PHost->setObjectName("labelI2PHost");

        i2pLayout->addWidget(labelI2PHost);

        textI2PHost = new QLineEdit(groupI2P);
        textI2PHost->setObjectName("textI2PHost");

        i2pLayout->addWidget(textI2PHost);

        labelI2PPort = new QLabel(groupI2P);
        labelI2PPort->setObjectName("labelI2PPort");

        i2pLayout->addWidget(labelI2PPort);

        spinI2PPort = new QSpinBox(groupI2P);
        spinI2PPort->setObjectName("spinI2PPort");
        spinI2PPort->setMinimum(1);
        spinI2PPort->setMaximum(65535);
        spinI2PPort->setValue(8080);

        i2pLayout->addWidget(spinI2PPort);

        horizontalSpacer_22 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        i2pLayout->addItem(horizontalSpacer_22);


        verticalLayout_40->addLayout(i2pLayout);

        checkI2PMixed = new QCheckBox(groupI2P);
        checkI2PMixed->setObjectName("checkI2PMixed");

        verticalLayout_40->addWidget(checkI2PMixed);


        verticalLayout_20->addWidget(groupI2P);

        groupProxy = new QGroupBox(scrollAreaWidgetContents_3);
        groupProxy->setObjectName("groupProxy");
        groupProxy->setEnabled(true);
        verticalLayout_29 = new QVBoxLayout(groupProxy);
        verticalLayout_29->setObjectName("verticalLayout_29");
        proxyTypeLayout = new QHBoxLayout();
        proxyTypeLayout->setObjectName("proxyTypeLayout");
        ProxyType_lbl = new QLabel(groupProxy);
        ProxyType_lbl->setObjectName("ProxyType_lbl");

        proxyTypeLayout->addWidget(ProxyType_lbl);

        comboProxyType = new QComboBox(groupProxy);
        comboProxyType->setObjectName("comboProxyType");

        proxyTypeLayout->addWidget(comboProxyType);

        lblProxyIP = new QLabel(groupProxy);
        lblProxyIP->setObjectName("lblProxyIP");

        proxyTypeLayout->addWidget(lblProxyIP);

        textProxyIP = new QLineEdit(groupProxy);
        textProxyIP->setObjectName("textProxyIP");

        proxyTypeLayout->addWidget(textProxyIP);

        lblProxyPort = new QLabel(groupProxy);
        lblProxyPort->setObjectName("lblProxyPort");

        proxyTypeLayout->addWidget(lblProxyPort);

        spinProxyPort = new QSpinBox(groupProxy);
        spinProxyPort->setObjectName("spinProxyPort");
        spinProxyPort->setMinimum(1);
        spinProxyPort->setMaximum(65535);
        spinProxyPort->setValue(8080);

        proxyTypeLayout->addWidget(spinProxyPort);

        horizontalSpacer_24 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        proxyTypeLayout->addItem(horizontalSpacer_24);


        verticalLayout_29->addLayout(proxyTypeLayout);

        labelProxyTypeUnavailable = new QLabel(groupProxy);
        labelProxyTypeUnavailable->setObjectName("labelProxyTypeUnavailable");
        labelProxyTypeUnavailable->setFont(font);

        verticalLayout_29->addWidget(labelProxyTypeUnavailable);

        checkProxyHostnameLookup = new QCheckBox(groupProxy);
        checkProxyHostnameLookup->setObjectName("checkProxyHostnameLookup");

        verticalLayout_29->addWidget(checkProxyHostnameLookup);

        checkProxyAuth = new QGroupBox(groupProxy);
        checkProxyAuth->setObjectName("checkProxyAuth");
        checkProxyAuth->setEnabled(false);
        checkProxyAuth->setCheckable(true);
        checkProxyAuth->setChecked(false);
        verticalLayout_24 = new QVBoxLayout(checkProxyAuth);
        verticalLayout_24->setObjectName("verticalLayout_24");
        gridLayout_12 = new QGridLayout();
        gridLayout_12->setObjectName("gridLayout_12");
        lblProxyUsername = new QLabel(checkProxyAuth);
        lblProxyUsername->setObjectName("lblProxyUsername");

        gridLayout_12->addWidget(lblProxyUsername, 0, 0, 1, 1);

        textProxyUsername = new QLineEdit(checkProxyAuth);
        textProxyUsername->setObjectName("textProxyUsername");

        gridLayout_12->addWidget(textProxyUsername, 0, 1, 1, 1);

        lblProxyPassword = new QLabel(checkProxyAuth);
        lblProxyPassword->setObjectName("lblProxyPassword");

        gridLayout_12->addWidget(lblProxyPassword, 1, 0, 1, 1);

        textProxyPassword = new QLineEdit(checkProxyAuth);
        textProxyPassword->setObjectName("textProxyPassword");
        textProxyPassword->setEchoMode(QLineEdit::EchoMode::Password);

        gridLayout_12->addWidget(textProxyPassword, 1, 1, 1, 1);


        verticalLayout_24->addLayout(gridLayout_12);

        label_23 = new QLabel(checkProxyAuth);
        label_23->setObjectName("label_23");

        verticalLayout_24->addWidget(label_23);


        verticalLayout_29->addWidget(checkProxyAuth);

        checkProxyBitTorrent = new QGroupBox(groupProxy);
        checkProxyBitTorrent->setObjectName("checkProxyBitTorrent");
        checkProxyBitTorrent->setCheckable(true);
        checkProxyBitTorrent->setChecked(false);
        verticalLayoutProxyBitTorrent = new QVBoxLayout(checkProxyBitTorrent);
        verticalLayoutProxyBitTorrent->setObjectName("verticalLayoutProxyBitTorrent");
        checkProxyPeerConnections = new QCheckBox(checkProxyBitTorrent);
        checkProxyPeerConnections->setObjectName("checkProxyPeerConnections");

        verticalLayoutProxyBitTorrent->addWidget(checkProxyPeerConnections);


        verticalLayout_29->addWidget(checkProxyBitTorrent);

        checkProxyRSS = new QCheckBox(groupProxy);
        checkProxyRSS->setObjectName("checkProxyRSS");
        checkProxyRSS->setChecked(false);

        verticalLayout_29->addWidget(checkProxyRSS);

        checkProxyMisc = new QCheckBox(groupProxy);
        checkProxyMisc->setObjectName("checkProxyMisc");
        checkProxyMisc->setChecked(false);

        verticalLayout_29->addWidget(checkProxyMisc);


        verticalLayout_20->addWidget(groupProxy);

        groupIPFilter = new QGroupBox(scrollAreaWidgetContents_3);
        groupIPFilter->setObjectName("groupIPFilter");
        verticalLayout_17 = new QVBoxLayout(groupIPFilter);
        verticalLayout_17->setObjectName("verticalLayout_17");
        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        checkIPFilter = new QCheckBox(groupIPFilter);
        checkIPFilter->setObjectName("checkIPFilter");

        horizontalLayout_11->addWidget(checkIPFilter);

        textFilterPath = new FileSystemPathLineEdit(groupIPFilter);
        textFilterPath->setObjectName("textFilterPath");

        horizontalLayout_11->addWidget(textFilterPath);

        IpFilterRefreshBtn = new QToolButton(groupIPFilter);
        IpFilterRefreshBtn->setObjectName("IpFilterRefreshBtn");

        horizontalLayout_11->addWidget(IpFilterRefreshBtn);


        verticalLayout_17->addLayout(horizontalLayout_11);

        banListButton = new QPushButton(groupIPFilter);
        banListButton->setObjectName("banListButton");
        sizePolicy1.setHeightForWidth(banListButton->sizePolicy().hasHeightForWidth());
        banListButton->setSizePolicy(sizePolicy1);

        verticalLayout_17->addWidget(banListButton);

        checkIpFilterTrackers = new QCheckBox(groupIPFilter);
        checkIpFilterTrackers->setObjectName("checkIpFilterTrackers");

        verticalLayout_17->addWidget(checkIpFilterTrackers);


        verticalLayout_20->addWidget(groupIPFilter);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_20->addItem(verticalSpacer_3);

        scrollArea_3->setWidget(scrollAreaWidgetContents_3);

        verticalLayout_6->addWidget(scrollArea_3);

        tabOption->addWidget(tabConnectionPage);
        tabSpeedPage = new QWidget();
        tabSpeedPage->setObjectName("tabSpeedPage");
        verticalLayout_34 = new QVBoxLayout(tabSpeedPage);
        verticalLayout_34->setObjectName("verticalLayout_34");
        verticalLayout_34->setContentsMargins(0, 0, 0, 0);
        scrollArea_9 = new QScrollArea(tabSpeedPage);
        scrollArea_9->setObjectName("scrollArea_9");
        scrollArea_9->setWidgetResizable(true);
        scrollAreaWidgetContents_9 = new QWidget();
        scrollAreaWidgetContents_9->setObjectName("scrollAreaWidgetContents_9");
        scrollAreaWidgetContents_9->setGeometry(QRect(0, 0, 302, 408));
        verticalLayout_5 = new QVBoxLayout(scrollAreaWidgetContents_9);
        verticalLayout_5->setObjectName("verticalLayout_5");
        rateLimitBox = new QGroupBox(scrollAreaWidgetContents_9);
        rateLimitBox->setObjectName("rateLimitBox");
        rateLimitBoxLayout = new QGridLayout(rateLimitBox);
        rateLimitBoxLayout->setObjectName("rateLimitBoxLayout");
        labelGlobalRate = new QLabel(rateLimitBox);
        labelGlobalRate->setObjectName("labelGlobalRate");

        rateLimitBoxLayout->addWidget(labelGlobalRate, 0, 0, 2, 1);

        label_10 = new QLabel(rateLimitBox);
        label_10->setObjectName("label_10");

        rateLimitBoxLayout->addWidget(label_10, 0, 1, 1, 1);

        spinUploadLimit = new QSpinBox(rateLimitBox);
        spinUploadLimit->setObjectName("spinUploadLimit");
        spinUploadLimit->setMaximum(2000000);
        spinUploadLimit->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);
        spinUploadLimit->setValue(100);

        rateLimitBoxLayout->addWidget(spinUploadLimit, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        rateLimitBoxLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        label_11 = new QLabel(rateLimitBox);
        label_11->setObjectName("label_11");

        rateLimitBoxLayout->addWidget(label_11, 1, 1, 1, 1);

        spinDownloadLimit = new QSpinBox(rateLimitBox);
        spinDownloadLimit->setObjectName("spinDownloadLimit");
        spinDownloadLimit->setMaximum(2000000);
        spinDownloadLimit->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);
        spinDownloadLimit->setValue(100);

        rateLimitBoxLayout->addWidget(spinDownloadLimit, 1, 2, 1, 1);


        verticalLayout_5->addWidget(rateLimitBox);

        altRateLimitBox = new QGroupBox(scrollAreaWidgetContents_9);
        altRateLimitBox->setObjectName("altRateLimitBox");
        gridLayout_6 = new QGridLayout(altRateLimitBox);
        gridLayout_6->setObjectName("gridLayout_6");
        labelAltRate = new QLabel(altRateLimitBox);
        labelAltRate->setObjectName("labelAltRate");

        gridLayout_6->addWidget(labelAltRate, 0, 0, 2, 1);

        label_13 = new QLabel(altRateLimitBox);
        label_13->setObjectName("label_13");

        gridLayout_6->addWidget(label_13, 0, 1, 1, 1);

        spinUploadLimitAlt = new QSpinBox(altRateLimitBox);
        spinUploadLimitAlt->setObjectName("spinUploadLimitAlt");
        spinUploadLimitAlt->setMaximum(2000000);
        spinUploadLimitAlt->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);
        spinUploadLimitAlt->setValue(10);

        gridLayout_6->addWidget(spinUploadLimitAlt, 0, 2, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_6->addItem(horizontalSpacer_5, 0, 3, 1, 1);

        label_14 = new QLabel(altRateLimitBox);
        label_14->setObjectName("label_14");

        gridLayout_6->addWidget(label_14, 1, 1, 1, 1);

        spinDownloadLimitAlt = new QSpinBox(altRateLimitBox);
        spinDownloadLimitAlt->setObjectName("spinDownloadLimitAlt");
        spinDownloadLimitAlt->setMaximum(2000000);
        spinDownloadLimitAlt->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);
        spinDownloadLimitAlt->setValue(10);

        gridLayout_6->addWidget(spinDownloadLimitAlt, 1, 2, 1, 1);

        groupBoxSchedule = new QGroupBox(altRateLimitBox);
        groupBoxSchedule->setObjectName("groupBoxSchedule");
        groupBoxSchedule->setCheckable(true);
        groupBoxSchedule->setChecked(false);
        gridLayout_7 = new QGridLayout(groupBoxSchedule);
        gridLayout_7->setObjectName("gridLayout_7");
        label_6 = new QLabel(groupBoxSchedule);
        label_6->setObjectName("label_6");

        gridLayout_7->addWidget(label_6, 0, 0, 1, 1);

        timeEditScheduleFrom = new QTimeEdit(groupBoxSchedule);
        timeEditScheduleFrom->setObjectName("timeEditScheduleFrom");
        timeEditScheduleFrom->setWrapping(true);
        timeEditScheduleFrom->setDisplayFormat(QString::fromUtf8("hh:mm"));
        timeEditScheduleFrom->setCalendarPopup(false);
        timeEditScheduleFrom->setTime(QTime(8, 0, 0));

        gridLayout_7->addWidget(timeEditScheduleFrom, 0, 1, 1, 1);

        label_17 = new QLabel(groupBoxSchedule);
        label_17->setObjectName("label_17");

        gridLayout_7->addWidget(label_17, 0, 2, 1, 1);

        timeEditScheduleTo = new QTimeEdit(groupBoxSchedule);
        timeEditScheduleTo->setObjectName("timeEditScheduleTo");
        timeEditScheduleTo->setWrapping(true);
        timeEditScheduleTo->setDisplayFormat(QString::fromUtf8("hh:mm"));
        timeEditScheduleTo->setTime(QTime(20, 0, 0));

        gridLayout_7->addWidget(timeEditScheduleTo, 0, 3, 1, 1);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_7->addItem(horizontalSpacer_8, 0, 4, 1, 1);

        label_18 = new QLabel(groupBoxSchedule);
        label_18->setObjectName("label_18");

        gridLayout_7->addWidget(label_18, 1, 0, 1, 1);

        comboBoxScheduleDays = new QComboBox(groupBoxSchedule);
        comboBoxScheduleDays->addItem(QString());
        comboBoxScheduleDays->addItem(QString());
        comboBoxScheduleDays->addItem(QString());
        comboBoxScheduleDays->setObjectName("comboBoxScheduleDays");
        sizePolicy1.setHeightForWidth(comboBoxScheduleDays->sizePolicy().hasHeightForWidth());
        comboBoxScheduleDays->setSizePolicy(sizePolicy1);

        gridLayout_7->addWidget(comboBoxScheduleDays, 1, 1, 1, 3);


        gridLayout_6->addWidget(groupBoxSchedule, 2, 0, 1, 4);


        verticalLayout_5->addWidget(altRateLimitBox);

        rateLimitsGroupBox = new QGroupBox(scrollAreaWidgetContents_9);
        rateLimitsGroupBox->setObjectName("rateLimitsGroupBox");
        verticalLayout_30 = new QVBoxLayout(rateLimitsGroupBox);
        verticalLayout_30->setObjectName("verticalLayout_30");
        checkLimituTPConnections = new QCheckBox(rateLimitsGroupBox);
        checkLimituTPConnections->setObjectName("checkLimituTPConnections");

        verticalLayout_30->addWidget(checkLimituTPConnections);

        checkLimitTransportOverhead = new QCheckBox(rateLimitsGroupBox);
        checkLimitTransportOverhead->setObjectName("checkLimitTransportOverhead");

        verticalLayout_30->addWidget(checkLimitTransportOverhead);

        checkLimitLocalPeerRate = new QCheckBox(rateLimitsGroupBox);
        checkLimitLocalPeerRate->setObjectName("checkLimitLocalPeerRate");

        verticalLayout_30->addWidget(checkLimitLocalPeerRate);


        verticalLayout_5->addWidget(rateLimitsGroupBox);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_2);

        scrollArea_9->setWidget(scrollAreaWidgetContents_9);

        verticalLayout_34->addWidget(scrollArea_9);

        tabOption->addWidget(tabSpeedPage);
        tabBitTorrentPage = new QWidget();
        tabBitTorrentPage->setObjectName("tabBitTorrentPage");
        verticalLayout_15 = new QVBoxLayout(tabBitTorrentPage);
        verticalLayout_15->setObjectName("verticalLayout_15");
        verticalLayout_15->setContentsMargins(0, 0, 0, 0);
        scrollArea_4 = new QScrollArea(tabBitTorrentPage);
        scrollArea_4->setObjectName("scrollArea_4");
        scrollArea_4->setWidgetResizable(true);
        scrollAreaWidgetContents_4 = new QWidget();
        scrollAreaWidgetContents_4->setObjectName("scrollAreaWidgetContents_4");
        scrollAreaWidgetContents_4->setGeometry(QRect(0, 0, 413, 693));
        verticalLayout_7 = new QVBoxLayout(scrollAreaWidgetContents_4);
        verticalLayout_7->setObjectName("verticalLayout_7");
        AddBTFeaturesBox = new QGroupBox(scrollAreaWidgetContents_4);
        AddBTFeaturesBox->setObjectName("AddBTFeaturesBox");
        verticalLayout_14 = new QVBoxLayout(AddBTFeaturesBox);
        verticalLayout_14->setObjectName("verticalLayout_14");
        checkDHT = new QCheckBox(AddBTFeaturesBox);
        checkDHT->setObjectName("checkDHT");
        checkDHT->setChecked(true);

        verticalLayout_14->addWidget(checkDHT);

        checkPeX = new QCheckBox(AddBTFeaturesBox);
        checkPeX->setObjectName("checkPeX");
        checkPeX->setChecked(true);

        verticalLayout_14->addWidget(checkPeX);

        checkLSD = new QCheckBox(AddBTFeaturesBox);
        checkLSD->setObjectName("checkLSD");
        checkLSD->setChecked(true);

        verticalLayout_14->addWidget(checkLSD);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        lbl_encryption = new QLabel(AddBTFeaturesBox);
        lbl_encryption->setObjectName("lbl_encryption");

        hboxLayout->addWidget(lbl_encryption);

        comboEncryption = new QComboBox(AddBTFeaturesBox);
        comboEncryption->addItem(QString());
        comboEncryption->addItem(QString());
        comboEncryption->addItem(QString());
        comboEncryption->setObjectName("comboEncryption");

        hboxLayout->addWidget(comboEncryption);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        verticalLayout_14->addLayout(hboxLayout);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        checkAnonymousMode = new QCheckBox(AddBTFeaturesBox);
        checkAnonymousMode->setObjectName("checkAnonymousMode");

        horizontalLayout_6->addWidget(checkAnonymousMode);

        label_anonymous = new QLabel(AddBTFeaturesBox);
        label_anonymous->setObjectName("label_anonymous");
        label_anonymous->setOpenExternalLinks(true);
        label_anonymous->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByKeyboard|Qt::TextInteractionFlag::LinksAccessibleByMouse);

        horizontalLayout_6->addWidget(label_anonymous);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_14);


        verticalLayout_14->addLayout(horizontalLayout_6);


        verticalLayout_7->addWidget(AddBTFeaturesBox);

        horizontalLayout_20 = new QHBoxLayout();
        horizontalLayout_20->setObjectName("horizontalLayout_20");
        labelMaxActiveCheckingTorrents = new QLabel(scrollAreaWidgetContents_4);
        labelMaxActiveCheckingTorrents->setObjectName("labelMaxActiveCheckingTorrents");

        horizontalLayout_20->addWidget(labelMaxActiveCheckingTorrents);

        spinBoxMaxActiveCheckingTorrents = new QSpinBox(scrollAreaWidgetContents_4);
        spinBoxMaxActiveCheckingTorrents->setObjectName("spinBoxMaxActiveCheckingTorrents");
        spinBoxMaxActiveCheckingTorrents->setSpecialValueText(QString::fromUtf8("\342\210\236"));
        spinBoxMaxActiveCheckingTorrents->setMinimum(-1);
        spinBoxMaxActiveCheckingTorrents->setMaximum(2147483647);

        horizontalLayout_20->addWidget(spinBoxMaxActiveCheckingTorrents);

        horizontalSpacer_21 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_20->addItem(horizontalSpacer_21);


        verticalLayout_7->addLayout(horizontalLayout_20);

        checkEnableQueueing = new QGroupBox(scrollAreaWidgetContents_4);
        checkEnableQueueing->setObjectName("checkEnableQueueing");
        checkEnableQueueing->setCheckable(true);
        checkEnableQueueing->setChecked(false);
        gridLayout_2 = new QGridLayout(checkEnableQueueing);
        gridLayout_2->setObjectName("gridLayout_2");
        label_max_active_dl = new QLabel(checkEnableQueueing);
        label_max_active_dl->setObjectName("label_max_active_dl");

        gridLayout_2->addWidget(label_max_active_dl, 0, 0, 1, 1);

        spinMaxActiveDownloads = new QSpinBox(checkEnableQueueing);
        spinMaxActiveDownloads->setObjectName("spinMaxActiveDownloads");
        spinMaxActiveDownloads->setMinimum(-1);
        spinMaxActiveDownloads->setMaximum(2147483647);

        gridLayout_2->addWidget(spinMaxActiveDownloads, 0, 1, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_7, 0, 2, 1, 1);

        label_max_active_up = new QLabel(checkEnableQueueing);
        label_max_active_up->setObjectName("label_max_active_up");

        gridLayout_2->addWidget(label_max_active_up, 1, 0, 1, 1);

        spinMaxActiveUploads = new QSpinBox(checkEnableQueueing);
        spinMaxActiveUploads->setObjectName("spinMaxActiveUploads");
        spinMaxActiveUploads->setMinimum(-1);
        spinMaxActiveUploads->setMaximum(2147483647);

        gridLayout_2->addWidget(spinMaxActiveUploads, 1, 1, 1, 1);

        maxActiveTorrents_lbl = new QLabel(checkEnableQueueing);
        maxActiveTorrents_lbl->setObjectName("maxActiveTorrents_lbl");

        gridLayout_2->addWidget(maxActiveTorrents_lbl, 2, 0, 1, 1);

        spinMaxActiveTorrents = new QSpinBox(checkEnableQueueing);
        spinMaxActiveTorrents->setObjectName("spinMaxActiveTorrents");
        spinMaxActiveTorrents->setMinimum(-1);
        spinMaxActiveTorrents->setMaximum(2147483647);

        gridLayout_2->addWidget(spinMaxActiveTorrents, 2, 1, 1, 1);

        checkIgnoreSlowTorrentsForQueueing = new QGroupBox(checkEnableQueueing);
        checkIgnoreSlowTorrentsForQueueing->setObjectName("checkIgnoreSlowTorrentsForQueueing");
        checkIgnoreSlowTorrentsForQueueing->setCheckable(true);
        checkIgnoreSlowTorrentsForQueueing->setChecked(false);
        gridLayout_13 = new QGridLayout(checkIgnoreSlowTorrentsForQueueing);
        gridLayout_13->setObjectName("gridLayout_13");
        labelDownloadRateForSlowTorrents = new QLabel(checkIgnoreSlowTorrentsForQueueing);
        labelDownloadRateForSlowTorrents->setObjectName("labelDownloadRateForSlowTorrents");

        gridLayout_13->addWidget(labelDownloadRateForSlowTorrents, 0, 0, 1, 1);

        spinDownloadRateForSlowTorrents = new QSpinBox(checkIgnoreSlowTorrentsForQueueing);
        spinDownloadRateForSlowTorrents->setObjectName("spinDownloadRateForSlowTorrents");
        spinDownloadRateForSlowTorrents->setMaximum(2000000);
        spinDownloadRateForSlowTorrents->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);
        spinDownloadRateForSlowTorrents->setValue(2);

        gridLayout_13->addWidget(spinDownloadRateForSlowTorrents, 0, 1, 1, 1);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_13->addItem(horizontalSpacer_9, 0, 2, 1, 1);

        labelUploadRateForSlowTorrents = new QLabel(checkIgnoreSlowTorrentsForQueueing);
        labelUploadRateForSlowTorrents->setObjectName("labelUploadRateForSlowTorrents");

        gridLayout_13->addWidget(labelUploadRateForSlowTorrents, 1, 0, 1, 1);

        spinUploadRateForSlowTorrents = new QSpinBox(checkIgnoreSlowTorrentsForQueueing);
        spinUploadRateForSlowTorrents->setObjectName("spinUploadRateForSlowTorrents");
        spinUploadRateForSlowTorrents->setMaximum(2000000);
        spinUploadRateForSlowTorrents->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);
        spinUploadRateForSlowTorrents->setValue(2);

        gridLayout_13->addWidget(spinUploadRateForSlowTorrents, 1, 1, 1, 1);

        labelSlowTorrentInactivityTimer = new QLabel(checkIgnoreSlowTorrentsForQueueing);
        labelSlowTorrentInactivityTimer->setObjectName("labelSlowTorrentInactivityTimer");

        gridLayout_13->addWidget(labelSlowTorrentInactivityTimer, 2, 0, 1, 1);

        spinSlowTorrentsInactivityTimer = new QSpinBox(checkIgnoreSlowTorrentsForQueueing);
        spinSlowTorrentsInactivityTimer->setObjectName("spinSlowTorrentsInactivityTimer");
        spinSlowTorrentsInactivityTimer->setMinimum(1);
        spinSlowTorrentsInactivityTimer->setMaximum(999999);
        spinSlowTorrentsInactivityTimer->setValue(60);

        gridLayout_13->addWidget(spinSlowTorrentsInactivityTimer, 2, 1, 1, 1);


        gridLayout_2->addWidget(checkIgnoreSlowTorrentsForQueueing, 3, 0, 1, 3);


        verticalLayout_7->addWidget(checkEnableQueueing);

        seedingLimitsBox = new QGroupBox(scrollAreaWidgetContents_4);
        seedingLimitsBox->setObjectName("seedingLimitsBox");
        gridLayout_15 = new QGridLayout(seedingLimitsBox);
        gridLayout_15->setObjectName("gridLayout_15");
        checkMaxRatio = new QCheckBox(seedingLimitsBox);
        checkMaxRatio->setObjectName("checkMaxRatio");

        gridLayout_15->addWidget(checkMaxRatio, 0, 0, 1, 1);

        spinMaxRatio = new QDoubleSpinBox(seedingLimitsBox);
        spinMaxRatio->setObjectName("spinMaxRatio");
        spinMaxRatio->setEnabled(false);
        spinMaxRatio->setSingleStep(0.050000000000000);
        spinMaxRatio->setValue(1.000000000000000);

        gridLayout_15->addWidget(spinMaxRatio, 0, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_15->addItem(horizontalSpacer_2, 0, 2, 1, 1);

        checkMaxSeedingMinutes = new QCheckBox(seedingLimitsBox);
        checkMaxSeedingMinutes->setObjectName("checkMaxSeedingMinutes");

        gridLayout_15->addWidget(checkMaxSeedingMinutes, 1, 0, 1, 1);

        spinMaxSeedingMinutes = new QSpinBox(seedingLimitsBox);
        spinMaxSeedingMinutes->setObjectName("spinMaxSeedingMinutes");
        spinMaxSeedingMinutes->setEnabled(false);
        spinMaxSeedingMinutes->setMaximum(9999999);
        spinMaxSeedingMinutes->setValue(1440);

        gridLayout_15->addWidget(spinMaxSeedingMinutes, 1, 1, 1, 1);

        checkMaxInactiveSeedingMinutes = new QCheckBox(seedingLimitsBox);
        checkMaxInactiveSeedingMinutes->setObjectName("checkMaxInactiveSeedingMinutes");

        gridLayout_15->addWidget(checkMaxInactiveSeedingMinutes, 2, 0, 1, 1);

        spinMaxInactiveSeedingMinutes = new QSpinBox(seedingLimitsBox);
        spinMaxInactiveSeedingMinutes->setObjectName("spinMaxInactiveSeedingMinutes");
        spinMaxInactiveSeedingMinutes->setEnabled(false);
        spinMaxInactiveSeedingMinutes->setMaximum(9999999);
        spinMaxInactiveSeedingMinutes->setValue(1440);

        gridLayout_15->addWidget(spinMaxInactiveSeedingMinutes, 2, 1, 1, 1);

        label = new QLabel(seedingLimitsBox);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_15->addWidget(label, 3, 0, 1, 1);

        comboRatioLimitAct = new QComboBox(seedingLimitsBox);
        comboRatioLimitAct->addItem(QString());
        comboRatioLimitAct->addItem(QString());
        comboRatioLimitAct->addItem(QString());
        comboRatioLimitAct->addItem(QString());
        comboRatioLimitAct->setObjectName("comboRatioLimitAct");
        comboRatioLimitAct->setEnabled(false);

        gridLayout_15->addWidget(comboRatioLimitAct, 3, 1, 1, 1);


        verticalLayout_7->addWidget(seedingLimitsBox);

        checkEnableAddTrackers = new QGroupBox(scrollAreaWidgetContents_4);
        checkEnableAddTrackers->setObjectName("checkEnableAddTrackers");
        checkEnableAddTrackers->setCheckable(true);
        checkEnableAddTrackers->setChecked(false);
        gridLayout_16 = new QGridLayout(checkEnableAddTrackers);
        gridLayout_16->setObjectName("gridLayout_16");
        textTrackers = new QPlainTextEdit(checkEnableAddTrackers);
        textTrackers->setObjectName("textTrackers");
        textTrackers->setTabChangesFocus(true);

        gridLayout_16->addWidget(textTrackers, 0, 0, 1, 1);


        verticalLayout_7->addWidget(checkEnableAddTrackers);

        checkAddTrackersFromURL = new QGroupBox(scrollAreaWidgetContents_4);
        checkAddTrackersFromURL->setObjectName("checkAddTrackersFromURL");
        checkAddTrackersFromURL->setCheckable(true);
        checkAddTrackersFromURL->setChecked(false);
        checkAddTrackersFromURLLayout = new QVBoxLayout(checkAddTrackersFromURL);
        checkAddTrackersFromURLLayout->setObjectName("checkAddTrackersFromURLLayout");
        horizontalLayout_21 = new QHBoxLayout();
        horizontalLayout_21->setObjectName("horizontalLayout_21");
        labelCustomizeTrackersListUrl = new QLabel(checkAddTrackersFromURL);
        labelCustomizeTrackersListUrl->setObjectName("labelCustomizeTrackersListUrl");

        horizontalLayout_21->addWidget(labelCustomizeTrackersListUrl);

        textTrackersURL = new QLineEdit(checkAddTrackersFromURL);
        textTrackersURL->setObjectName("textTrackersURL");

        horizontalLayout_21->addWidget(textTrackersURL);


        checkAddTrackersFromURLLayout->addLayout(horizontalLayout_21);

        labeltrackersFromURL = new QLabel(checkAddTrackersFromURL);
        labeltrackersFromURL->setObjectName("labeltrackersFromURL");

        checkAddTrackersFromURLLayout->addWidget(labeltrackersFromURL);

        textTrackersFromURL = new QPlainTextEdit(checkAddTrackersFromURL);
        textTrackersFromURL->setObjectName("textTrackersFromURL");
        textTrackersFromURL->setReadOnly(true);

        checkAddTrackersFromURLLayout->addWidget(textTrackersFromURL);


        verticalLayout_7->addWidget(checkAddTrackersFromURL);

        verticalSpacer_8 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_7->addItem(verticalSpacer_8);

        scrollArea_4->setWidget(scrollAreaWidgetContents_4);

        verticalLayout_15->addWidget(scrollArea_4);

        tabOption->addWidget(tabBitTorrentPage);
        tabSearchPage = new QWidget();
        tabSearchPage->setObjectName("tabSearchPage");
        searchPageLayout = new QVBoxLayout(tabSearchPage);
        searchPageLayout->setObjectName("searchPageLayout");
        searchPageLayout->setContentsMargins(0, 0, 0, 0);
        searchPageScrollArea = new QScrollArea(tabSearchPage);
        searchPageScrollArea->setObjectName("searchPageScrollArea");
        searchPageScrollArea->setWidgetResizable(true);
        searchPageScrollAreaWidgetContents = new QWidget();
        searchPageScrollAreaWidgetContents->setObjectName("searchPageScrollAreaWidgetContents");
        searchPageScrollAreaWidgetContents->setGeometry(QRect(0, 0, 521, 541));
        searchPageScrollAreaWidgetContentsLayout = new QVBoxLayout(searchPageScrollAreaWidgetContents);
        searchPageScrollAreaWidgetContentsLayout->setObjectName("searchPageScrollAreaWidgetContentsLayout");
        groupSearchUI = new QGroupBox(searchPageScrollAreaWidgetContents);
        groupSearchUI->setObjectName("groupSearchUI");
        groupSearchUILayout = new QVBoxLayout(groupSearchUI);
        groupSearchUILayout->setObjectName("groupSearchUILayout");
        groupStoreOpenedTabs = new QGroupBox(groupSearchUI);
        groupStoreOpenedTabs->setObjectName("groupStoreOpenedTabs");
        groupStoreOpenedTabs->setCheckable(true);
        groupStoreOpenedTabs->setChecked(false);
        groupStoreOpenedTabsLayout = new QVBoxLayout(groupStoreOpenedTabs);
        groupStoreOpenedTabsLayout->setObjectName("groupStoreOpenedTabsLayout");
        checkStoreTabsSearchResults = new QCheckBox(groupStoreOpenedTabs);
        checkStoreTabsSearchResults->setObjectName("checkStoreTabsSearchResults");

        groupStoreOpenedTabsLayout->addWidget(checkStoreTabsSearchResults);


        groupSearchUILayout->addWidget(groupStoreOpenedTabs);

        searchHistoryLayout = new QHBoxLayout();
        searchHistoryLayout->setObjectName("searchHistoryLayout");
        searchHistoryLengthLabel = new QLabel(groupSearchUI);
        searchHistoryLengthLabel->setObjectName("searchHistoryLengthLabel");

        searchHistoryLayout->addWidget(searchHistoryLengthLabel);

        searchHistoryLengthSpinBox = new QSpinBox(groupSearchUI);
        searchHistoryLengthSpinBox->setObjectName("searchHistoryLengthSpinBox");
        searchHistoryLengthSpinBox->setMaximum(99);

        searchHistoryLayout->addWidget(searchHistoryLengthSpinBox);

        searchHistoryLengthSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        searchHistoryLayout->addItem(searchHistoryLengthSpacer);


        groupSearchUILayout->addLayout(searchHistoryLayout);


        searchPageScrollAreaWidgetContentsLayout->addWidget(groupSearchUI);

        searchPageScrollAreaSpacer = new QSpacerItem(20, 422, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        searchPageScrollAreaWidgetContentsLayout->addItem(searchPageScrollAreaSpacer);

        searchPageScrollArea->setWidget(searchPageScrollAreaWidgetContents);

        searchPageLayout->addWidget(searchPageScrollArea);

        tabOption->addWidget(tabSearchPage);
        tabRSSPage = new QWidget();
        tabRSSPage->setObjectName("tabRSSPage");
        verticalLayout_25 = new QVBoxLayout(tabRSSPage);
        verticalLayout_25->setObjectName("verticalLayout_25");
        verticalLayout_25->setContentsMargins(0, 0, 0, 0);
        scrollArea_5 = new QScrollArea(tabRSSPage);
        scrollArea_5->setObjectName("scrollArea_5");
        scrollArea_5->setWidgetResizable(true);
        scrollAreaWidgetContents_5 = new QWidget();
        scrollAreaWidgetContents_5->setObjectName("scrollAreaWidgetContents_5");
        scrollAreaWidgetContents_5->setGeometry(QRect(0, 0, 336, 391));
        verticalLayout_27 = new QVBoxLayout(scrollAreaWidgetContents_5);
        verticalLayout_27->setObjectName("verticalLayout_27");
        groupRSSReader = new QGroupBox(scrollAreaWidgetContents_5);
        groupRSSReader->setObjectName("groupRSSReader");
        verticalLayout_26 = new QVBoxLayout(groupRSSReader);
        verticalLayout_26->setObjectName("verticalLayout_26");
        checkRSSEnable = new QCheckBox(groupRSSReader);
        checkRSSEnable->setObjectName("checkRSSEnable");

        verticalLayout_26->addWidget(checkRSSEnable);

        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName("gridLayout_5");
        label_111 = new QLabel(groupRSSReader);
        label_111->setObjectName("label_111");

        gridLayout_5->addWidget(label_111, 0, 0, 1, 1);

        spinRSSRefreshInterval = new QSpinBox(groupRSSReader);
        spinRSSRefreshInterval->setObjectName("spinRSSRefreshInterval");
        spinRSSRefreshInterval->setMinimum(1);
        spinRSSRefreshInterval->setMaximum(999999);
        spinRSSRefreshInterval->setValue(5);

        gridLayout_5->addWidget(spinRSSRefreshInterval, 0, 1, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_6, 0, 2, 1, 1);

        labelRSSFetchDelay = new QLabel(groupRSSReader);
        labelRSSFetchDelay->setObjectName("labelRSSFetchDelay");

        gridLayout_5->addWidget(labelRSSFetchDelay, 1, 0, 1, 1);

        spinRSSFetchDelay = new QSpinBox(groupRSSReader);
        spinRSSFetchDelay->setObjectName("spinRSSFetchDelay");
        spinRSSFetchDelay->setMaximum(2147483646);
        spinRSSFetchDelay->setValue(2);

        gridLayout_5->addWidget(spinRSSFetchDelay, 1, 1, 1, 1);

        label_12 = new QLabel(groupRSSReader);
        label_12->setObjectName("label_12");

        gridLayout_5->addWidget(label_12, 2, 0, 1, 1);

        spinRSSMaxArticlesPerFeed = new QSpinBox(groupRSSReader);
        spinRSSMaxArticlesPerFeed->setObjectName("spinRSSMaxArticlesPerFeed");
        spinRSSMaxArticlesPerFeed->setMaximum(2147483646);
        spinRSSMaxArticlesPerFeed->setValue(100);

        gridLayout_5->addWidget(spinRSSMaxArticlesPerFeed, 2, 1, 1, 1);


        verticalLayout_26->addLayout(gridLayout_5);


        verticalLayout_27->addWidget(groupRSSReader);

        groupRSSAutoDownloader = new QGroupBox(scrollAreaWidgetContents_5);
        groupRSSAutoDownloader->setObjectName("groupRSSAutoDownloader");
        verticalLayout_21 = new QVBoxLayout(groupRSSAutoDownloader);
        verticalLayout_21->setObjectName("verticalLayout_21");
        checkRSSAutoDownloaderEnable = new QCheckBox(groupRSSAutoDownloader);
        checkRSSAutoDownloaderEnable->setObjectName("checkRSSAutoDownloaderEnable");

        verticalLayout_21->addWidget(checkRSSAutoDownloaderEnable);

        btnEditRules = new QPushButton(groupRSSAutoDownloader);
        btnEditRules->setObjectName("btnEditRules");

        verticalLayout_21->addWidget(btnEditRules);


        verticalLayout_27->addWidget(groupRSSAutoDownloader);

        groupRSSSmartEpisodeFilter = new QGroupBox(scrollAreaWidgetContents_5);
        groupRSSSmartEpisodeFilter->setObjectName("groupRSSSmartEpisodeFilter");
        verticalLayout_31 = new QVBoxLayout(groupRSSSmartEpisodeFilter);
        verticalLayout_31->setObjectName("verticalLayout_31");
        checkSmartFilterDownloadRepacks = new QCheckBox(groupRSSSmartEpisodeFilter);
        checkSmartFilterDownloadRepacks->setObjectName("checkSmartFilterDownloadRepacks");

        verticalLayout_31->addWidget(checkSmartFilterDownloadRepacks);

        label_5 = new QLabel(groupRSSSmartEpisodeFilter);
        label_5->setObjectName("label_5");

        verticalLayout_31->addWidget(label_5);

        textSmartEpisodeFilters = new QPlainTextEdit(groupRSSSmartEpisodeFilter);
        textSmartEpisodeFilters->setObjectName("textSmartEpisodeFilters");
        textSmartEpisodeFilters->setTabChangesFocus(true);

        verticalLayout_31->addWidget(textSmartEpisodeFilters);


        verticalLayout_27->addWidget(groupRSSSmartEpisodeFilter);

        verticalSpacer_5 = new QSpacerItem(20, 200, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_27->addItem(verticalSpacer_5);

        scrollArea_5->setWidget(scrollAreaWidgetContents_5);

        verticalLayout_25->addWidget(scrollArea_5);

        tabOption->addWidget(tabRSSPage);
        tabWebUIPage = new QWidget();
        tabWebUIPage->setObjectName("tabWebUIPage");
        tabWebUIPageLayout = new QVBoxLayout(tabWebUIPage);
        tabWebUIPageLayout->setObjectName("tabWebUIPageLayout");
        tabWebUIPageLayout->setContentsMargins(0, 0, 0, 0);
        scrollArea_7 = new QScrollArea(tabWebUIPage);
        scrollArea_7->setObjectName("scrollArea_7");
        scrollArea_7->setWidgetResizable(true);
        scrollAreaWidgetContents_7 = new QWidget();
        scrollAreaWidgetContents_7->setObjectName("scrollAreaWidgetContents_7");
        scrollAreaWidgetContents_7->setGeometry(QRect(0, 0, 382, 1045));
        verticalLayout_23 = new QVBoxLayout(scrollAreaWidgetContents_7);
        verticalLayout_23->setObjectName("verticalLayout_23");
        checkWebUI = new QGroupBox(scrollAreaWidgetContents_7);
        checkWebUI->setObjectName("checkWebUI");
        checkWebUI->setCheckable(true);
        checkWebUI->setChecked(false);
        verticalLayout_2 = new QVBoxLayout(checkWebUI);
        verticalLayout_2->setObjectName("verticalLayout_2");
        labelWebUIError = new QLabel(checkWebUI);
        labelWebUIError->setObjectName("labelWebUIError");
        labelWebUIError->setFont(font);

        verticalLayout_2->addWidget(labelWebUIError);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        lblWebUIAddress = new QLabel(checkWebUI);
        lblWebUIAddress->setObjectName("lblWebUIAddress");

        horizontalLayout_2->addWidget(lblWebUIAddress);

        textWebUIAddress = new QLineEdit(checkWebUI);
        textWebUIAddress->setObjectName("textWebUIAddress");

        horizontalLayout_2->addWidget(textWebUIAddress);

        lblWebUIPort = new QLabel(checkWebUI);
        lblWebUIPort->setObjectName("lblWebUIPort");

        horizontalLayout_2->addWidget(lblWebUIPort);

        spinWebUIPort = new QSpinBox(checkWebUI);
        spinWebUIPort->setObjectName("spinWebUIPort");
        spinWebUIPort->setMinimum(1);
        spinWebUIPort->setMaximum(65535);
        spinWebUIPort->setValue(8080);

        horizontalLayout_2->addWidget(spinWebUIPort);


        verticalLayout_2->addLayout(horizontalLayout_2);

        checkWebUIUPnP = new QCheckBox(checkWebUI);
        checkWebUIUPnP->setObjectName("checkWebUIUPnP");
        checkWebUIUPnP->setChecked(true);

        verticalLayout_2->addWidget(checkWebUIUPnP);

        checkWebUIHttps = new QGroupBox(checkWebUI);
        checkWebUIHttps->setObjectName("checkWebUIHttps");
        checkWebUIHttps->setCheckable(true);
        checkWebUIHttps->setChecked(false);
        gridLayout_11 = new QGridLayout(checkWebUIHttps);
        gridLayout_11->setObjectName("gridLayout_11");
        lblSslCertStatus = new QLabel(checkWebUIHttps);
        lblSslCertStatus->setObjectName("lblSslCertStatus");

        gridLayout_11->addWidget(lblSslCertStatus, 0, 0, 1, 1);

        lblWebUICrt = new QLabel(checkWebUIHttps);
        lblWebUICrt->setObjectName("lblWebUICrt");

        gridLayout_11->addWidget(lblWebUICrt, 0, 1, 1, 1);

        textWebUIHttpsCert = new FileSystemPathLineEdit(checkWebUIHttps);
        textWebUIHttpsCert->setObjectName("textWebUIHttpsCert");

        gridLayout_11->addWidget(textWebUIHttpsCert, 0, 2, 1, 1);

        lblSslKeyStatus = new QLabel(checkWebUIHttps);
        lblSslKeyStatus->setObjectName("lblSslKeyStatus");

        gridLayout_11->addWidget(lblSslKeyStatus, 1, 0, 1, 1);

        lblWebUIKey = new QLabel(checkWebUIHttps);
        lblWebUIKey->setObjectName("lblWebUIKey");

        gridLayout_11->addWidget(lblWebUIKey, 1, 1, 1, 1);

        textWebUIHttpsKey = new FileSystemPathLineEdit(checkWebUIHttps);
        textWebUIHttpsKey->setObjectName("textWebUIHttpsKey");

        gridLayout_11->addWidget(textWebUIHttpsKey, 1, 2, 1, 1);

        lblWebUICertInfo = new QLabel(checkWebUIHttps);
        lblWebUICertInfo->setObjectName("lblWebUICertInfo");
        lblWebUICertInfo->setOpenExternalLinks(true);
        lblWebUICertInfo->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByKeyboard|Qt::TextInteractionFlag::LinksAccessibleByMouse);

        gridLayout_11->addWidget(lblWebUICertInfo, 2, 0, 1, 3);


        verticalLayout_2->addWidget(checkWebUIHttps);

        groupWebUIAuth = new QGroupBox(checkWebUI);
        groupWebUIAuth->setObjectName("groupWebUIAuth");
        verticalLayout_35 = new QVBoxLayout(groupWebUIAuth);
        verticalLayout_35->setObjectName("verticalLayout_35");
        groupWebUIUser = new QGroupBox(groupWebUIAuth);
        groupWebUIUser->setObjectName("groupWebUIUser");
        gridLayoutUser = new QGridLayout(groupWebUIUser);
        gridLayoutUser->setObjectName("gridLayoutUser");
        lblWebUIUsername = new QLabel(groupWebUIUser);
        lblWebUIUsername->setObjectName("lblWebUIUsername");

        gridLayoutUser->addWidget(lblWebUIUsername, 0, 0, 1, 1);

        textWebUIUsername = new QLineEdit(groupWebUIUser);
        textWebUIUsername->setObjectName("textWebUIUsername");

        gridLayoutUser->addWidget(textWebUIUsername, 0, 1, 1, 1);

        lblWebUIPassword = new QLabel(groupWebUIUser);
        lblWebUIPassword->setObjectName("lblWebUIPassword");

        gridLayoutUser->addWidget(lblWebUIPassword, 1, 0, 1, 1);

        textWebUIPassword = new QLineEdit(groupWebUIUser);
        textWebUIPassword->setObjectName("textWebUIPassword");
        textWebUIPassword->setEchoMode(QLineEdit::EchoMode::Password);

        gridLayoutUser->addWidget(textWebUIPassword, 1, 1, 1, 1);


        verticalLayout_35->addWidget(groupWebUIUser);

        groupWebUIAPIKey = new QGroupBox(groupWebUIAuth);
        groupWebUIAPIKey->setObjectName("groupWebUIAPIKey");
        gridLayoutAPIKey = new QGridLayout(groupWebUIAPIKey);
        gridLayoutAPIKey->setObjectName("gridLayoutAPIKey");
        lblWebUIAPIKey = new QLabel(groupWebUIAPIKey);
        lblWebUIAPIKey->setObjectName("lblWebUIAPIKey");

        gridLayoutAPIKey->addWidget(lblWebUIAPIKey, 0, 0, 1, 1);

        horizontalLayoutAPIKey = new QHBoxLayout();
        horizontalLayoutAPIKey->setObjectName("horizontalLayoutAPIKey");
        textWebUIAPIKey = new QLineEdit(groupWebUIAPIKey);
        textWebUIAPIKey->setObjectName("textWebUIAPIKey");
        textWebUIAPIKey->setReadOnly(true);

        horizontalLayoutAPIKey->addWidget(textWebUIAPIKey);

        btnWebUIAPIKeyCopy = new QPushButton(groupWebUIAPIKey);
        btnWebUIAPIKeyCopy->setObjectName("btnWebUIAPIKeyCopy");
        btnWebUIAPIKeyCopy->setEnabled(false);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/edit-copy.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        btnWebUIAPIKeyCopy->setIcon(icon);

        horizontalLayoutAPIKey->addWidget(btnWebUIAPIKeyCopy);

        btnWebUIAPIKeyRotate = new QPushButton(groupWebUIAPIKey);
        btnWebUIAPIKeyRotate->setObjectName("btnWebUIAPIKeyRotate");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/view-refresh.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        btnWebUIAPIKeyRotate->setIcon(icon1);

        horizontalLayoutAPIKey->addWidget(btnWebUIAPIKeyRotate);

        btnWebUIAPIKeyDelete = new QPushButton(groupWebUIAPIKey);
        btnWebUIAPIKeyDelete->setObjectName("btnWebUIAPIKeyDelete");
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/icons/list-remove.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        btnWebUIAPIKeyDelete->setIcon(icon2);

        horizontalLayoutAPIKey->addWidget(btnWebUIAPIKeyDelete);


        gridLayoutAPIKey->addLayout(horizontalLayoutAPIKey, 0, 1, 1, 1);


        verticalLayout_35->addWidget(groupWebUIAPIKey);

        checkBypassLocalAuth = new QCheckBox(groupWebUIAuth);
        checkBypassLocalAuth->setObjectName("checkBypassLocalAuth");

        verticalLayout_35->addWidget(checkBypassLocalAuth);

        checkBypassAuthSubnetWhitelist = new QCheckBox(groupWebUIAuth);
        checkBypassAuthSubnetWhitelist->setObjectName("checkBypassAuthSubnetWhitelist");

        verticalLayout_35->addWidget(checkBypassAuthSubnetWhitelist);

        IPSubnetWhitelistButton = new QPushButton(groupWebUIAuth);
        IPSubnetWhitelistButton->setObjectName("IPSubnetWhitelistButton");
        sizePolicy1.setHeightForWidth(IPSubnetWhitelistButton->sizePolicy().hasHeightForWidth());
        IPSubnetWhitelistButton->setSizePolicy(sizePolicy1);

        verticalLayout_35->addWidget(IPSubnetWhitelistButton);

        gridLayout_10 = new QGridLayout();
        gridLayout_10->setObjectName("gridLayout_10");
        lblBanCounter = new QLabel(groupWebUIAuth);
        lblBanCounter->setObjectName("lblBanCounter");

        gridLayout_10->addWidget(lblBanCounter, 0, 0, 1, 1);

        spinBanCounter = new QSpinBox(groupWebUIAuth);
        spinBanCounter->setObjectName("spinBanCounter");
        spinBanCounter->setMaximum(2147483647);

        gridLayout_10->addWidget(spinBanCounter, 0, 1, 1, 1);

        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_10->addItem(horizontalSpacer_15, 0, 2, 1, 1);

        lblBanDuration = new QLabel(groupWebUIAuth);
        lblBanDuration->setObjectName("lblBanDuration");
        lblBanDuration->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_10->addWidget(lblBanDuration, 1, 0, 1, 1);

        spinBanDuration = new QSpinBox(groupWebUIAuth);
        spinBanDuration->setObjectName("spinBanDuration");
        spinBanDuration->setMinimum(1);
        spinBanDuration->setMaximum(2147483647);

        gridLayout_10->addWidget(spinBanDuration, 1, 1, 1, 1);


        verticalLayout_35->addLayout(gridLayout_10);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        lblSessionTimeout = new QLabel(groupWebUIAuth);
        lblSessionTimeout->setObjectName("lblSessionTimeout");

        horizontalLayout_13->addWidget(lblSessionTimeout);

        spinSessionTimeout = new QSpinBox(groupWebUIAuth);
        spinSessionTimeout->setObjectName("spinSessionTimeout");
        spinSessionTimeout->setMaximum(2147483647);

        horizontalLayout_13->addWidget(spinSessionTimeout);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_11);


        verticalLayout_35->addLayout(horizontalLayout_13);


        verticalLayout_2->addWidget(groupWebUIAuth);

        groupAltWebUI = new QGroupBox(checkWebUI);
        groupAltWebUI->setObjectName("groupAltWebUI");
        groupAltWebUI->setCheckable(true);
        groupAltWebUI->setChecked(false);
        verticalLayout_41 = new QVBoxLayout(groupAltWebUI);
        verticalLayout_41->setObjectName("verticalLayout_41");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        labelWebUIRootFolder = new QLabel(groupAltWebUI);
        labelWebUIRootFolder->setObjectName("labelWebUIRootFolder");

        horizontalLayout_5->addWidget(labelWebUIRootFolder);

        textWebUIRootFolder = new FileSystemPathLineEdit(groupAltWebUI);
        textWebUIRootFolder->setObjectName("textWebUIRootFolder");

        horizontalLayout_5->addWidget(textWebUIRootFolder);


        verticalLayout_41->addLayout(horizontalLayout_5);

        lblAltWebUIList = new QLabel(groupAltWebUI);
        lblAltWebUIList->setObjectName("lblAltWebUIList");
        lblAltWebUIList->setOpenExternalLinks(true);
        lblAltWebUIList->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByKeyboard|Qt::TextInteractionFlag::LinksAccessibleByMouse);

        verticalLayout_41->addWidget(lblAltWebUIList);


        verticalLayout_2->addWidget(groupAltWebUI);

        groupBox_3 = new QGroupBox(checkWebUI);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_33 = new QVBoxLayout(groupBox_3);
        verticalLayout_33->setObjectName("verticalLayout_33");
        checkClickjacking = new QCheckBox(groupBox_3);
        checkClickjacking->setObjectName("checkClickjacking");

        verticalLayout_33->addWidget(checkClickjacking);

        checkCSRFProtection = new QCheckBox(groupBox_3);
        checkCSRFProtection->setObjectName("checkCSRFProtection");

        verticalLayout_33->addWidget(checkCSRFProtection);

        checkSecureCookie = new QCheckBox(groupBox_3);
        checkSecureCookie->setObjectName("checkSecureCookie");

        verticalLayout_33->addWidget(checkSecureCookie);

        groupHostHeaderValidation = new QGroupBox(groupBox_3);
        groupHostHeaderValidation->setObjectName("groupHostHeaderValidation");
        groupHostHeaderValidation->setCheckable(true);
        verticalLayout_32 = new QVBoxLayout(groupHostHeaderValidation);
        verticalLayout_32->setObjectName("verticalLayout_32");
        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        labelServerDomains = new QLabel(groupHostHeaderValidation);
        labelServerDomains->setObjectName("labelServerDomains");

        horizontalLayout_10->addWidget(labelServerDomains);

        textServerDomains = new QLineEdit(groupHostHeaderValidation);
        textServerDomains->setObjectName("textServerDomains");

        horizontalLayout_10->addWidget(textServerDomains);


        verticalLayout_32->addLayout(horizontalLayout_10);


        verticalLayout_33->addWidget(groupHostHeaderValidation);


        verticalLayout_2->addWidget(groupBox_3);

        groupWebUIAddCustomHTTPHeaders = new QGroupBox(checkWebUI);
        groupWebUIAddCustomHTTPHeaders->setObjectName("groupWebUIAddCustomHTTPHeaders");
        groupWebUIAddCustomHTTPHeaders->setCheckable(true);
        verticalLayout_8 = new QVBoxLayout(groupWebUIAddCustomHTTPHeaders);
        verticalLayout_8->setObjectName("verticalLayout_8");
        textWebUICustomHTTPHeaders = new QPlainTextEdit(groupWebUIAddCustomHTTPHeaders);
        textWebUICustomHTTPHeaders->setObjectName("textWebUICustomHTTPHeaders");
        textWebUICustomHTTPHeaders->setTabChangesFocus(true);
        textWebUICustomHTTPHeaders->setLineWrapMode(QPlainTextEdit::LineWrapMode::NoWrap);

        verticalLayout_8->addWidget(textWebUICustomHTTPHeaders);


        verticalLayout_2->addWidget(groupWebUIAddCustomHTTPHeaders);

        groupEnableReverseProxySupport = new QGroupBox(checkWebUI);
        groupEnableReverseProxySupport->setObjectName("groupEnableReverseProxySupport");
        groupEnableReverseProxySupport->setCheckable(true);
        verticalLayout_331 = new QVBoxLayout(groupEnableReverseProxySupport);
        verticalLayout_331->setObjectName("verticalLayout_331");
        horizontalLayout_131 = new QHBoxLayout();
        horizontalLayout_131->setObjectName("horizontalLayout_131");
        lblReverseProxiesList = new QLabel(groupEnableReverseProxySupport);
        lblReverseProxiesList->setObjectName("lblReverseProxiesList");

        horizontalLayout_131->addWidget(lblReverseProxiesList);

        textTrustedReverseProxiesList = new QLineEdit(groupEnableReverseProxySupport);
        textTrustedReverseProxiesList->setObjectName("textTrustedReverseProxiesList");

        horizontalLayout_131->addWidget(textTrustedReverseProxiesList);


        verticalLayout_331->addLayout(horizontalLayout_131);

        labelReverseProxyLink = new QLabel(groupEnableReverseProxySupport);
        labelReverseProxyLink->setObjectName("labelReverseProxyLink");
        labelReverseProxyLink->setOpenExternalLinks(true);
        labelReverseProxyLink->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByKeyboard|Qt::TextInteractionFlag::LinksAccessibleByMouse);

        verticalLayout_331->addWidget(labelReverseProxyLink);


        verticalLayout_2->addWidget(groupEnableReverseProxySupport);

        checkDynDNS = new QGroupBox(checkWebUI);
        checkDynDNS->setObjectName("checkDynDNS");
        checkDynDNS->setCheckable(true);
        checkDynDNS->setChecked(false);
        formLayout_5 = new QFormLayout(checkDynDNS);
        formLayout_5->setObjectName("formLayout_5");
        label_19 = new QLabel(checkDynDNS);
        label_19->setObjectName("label_19");

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, label_19);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        comboDNSService = new QComboBox(checkDynDNS);
        comboDNSService->addItem(QString::fromUtf8("DynDNS"));
        comboDNSService->addItem(QString::fromUtf8("No-IP"));
        comboDNSService->setObjectName("comboDNSService");

        horizontalLayout_3->addWidget(comboDNSService);

        registerDNSBtn = new QPushButton(checkDynDNS);
        registerDNSBtn->setObjectName("registerDNSBtn");

        horizontalLayout_3->addWidget(registerDNSBtn);


        formLayout_5->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        label_20 = new QLabel(checkDynDNS);
        label_20->setObjectName("label_20");

        formLayout_5->setWidget(1, QFormLayout::ItemRole::LabelRole, label_20);

        domainNameTxt = new QLineEdit(checkDynDNS);
        domainNameTxt->setObjectName("domainNameTxt");
        domainNameTxt->setText(QString::fromUtf8("changeme.dyndns.org"));

        formLayout_5->setWidget(1, QFormLayout::ItemRole::FieldRole, domainNameTxt);

        label_21 = new QLabel(checkDynDNS);
        label_21->setObjectName("label_21");

        formLayout_5->setWidget(2, QFormLayout::ItemRole::LabelRole, label_21);

        DNSUsernameTxt = new QLineEdit(checkDynDNS);
        DNSUsernameTxt->setObjectName("DNSUsernameTxt");

        formLayout_5->setWidget(2, QFormLayout::ItemRole::FieldRole, DNSUsernameTxt);

        label_22 = new QLabel(checkDynDNS);
        label_22->setObjectName("label_22");

        formLayout_5->setWidget(3, QFormLayout::ItemRole::LabelRole, label_22);

        DNSPasswordTxt = new QLineEdit(checkDynDNS);
        DNSPasswordTxt->setObjectName("DNSPasswordTxt");
        DNSPasswordTxt->setEchoMode(QLineEdit::EchoMode::Password);

        formLayout_5->setWidget(3, QFormLayout::ItemRole::FieldRole, DNSPasswordTxt);


        verticalLayout_2->addWidget(checkDynDNS);


        verticalLayout_23->addWidget(checkWebUI);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_23->addItem(verticalSpacer);

        scrollArea_7->setWidget(scrollAreaWidgetContents_7);

        tabWebUIPageLayout->addWidget(scrollArea_7);

        tabOption->addWidget(tabWebUIPage);
        tabAdvancedPage = new QWidget();
        tabAdvancedPage->setObjectName("tabAdvancedPage");
        advPageLayout = new QVBoxLayout(tabAdvancedPage);
        advPageLayout->setObjectName("advPageLayout");
        advPageLayout->setContentsMargins(0, 0, 0, 0);
        tabOption->addWidget(tabAdvancedPage);
        hsplitter->addWidget(tabOption);

        verticalLayout_3->addWidget(hsplitter);

        buttonBox = new QDialogButtonBox(OptionsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Apply|QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout_3->addWidget(buttonBox);


        retranslateUi(OptionsDialog);

        tabSelection->setCurrentRow(0);
        tabOption->setCurrentIndex(0);
        actionTorrentDlOnDblClBox->setCurrentIndex(0);
        comboFileLogAgeType->setCurrentIndex(1);
        contentLayoutComboBox->setCurrentIndex(0);
        stopConditionComboBox->setCurrentIndex(0);
        comboCategoryDefaultPathChanged->setCurrentIndex(1);
        comboCategoryChanged->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(OptionsDialog);
    } // setupUi

    void retranslateUi(QDialog *OptionsDialog)
    {
        OptionsDialog->setWindowTitle(QCoreApplication::translate("OptionsDialog", "Options", nullptr));

        const bool __sortingEnabled = tabSelection->isSortingEnabled();
        tabSelection->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = tabSelection->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("OptionsDialog", "Behavior", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = tabSelection->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("OptionsDialog", "Downloads", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = tabSelection->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("OptionsDialog", "Connection", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = tabSelection->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("OptionsDialog", "Speed", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = tabSelection->item(4);
        ___qlistwidgetitem4->setText(QCoreApplication::translate("OptionsDialog", "BitTorrent", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = tabSelection->item(5);
        ___qlistwidgetitem5->setText(QCoreApplication::translate("OptionsDialog", "Search", nullptr));
        QListWidgetItem *___qlistwidgetitem6 = tabSelection->item(6);
        ___qlistwidgetitem6->setText(QCoreApplication::translate("OptionsDialog", "RSS", nullptr));
        QListWidgetItem *___qlistwidgetitem7 = tabSelection->item(7);
        ___qlistwidgetitem7->setText(QCoreApplication::translate("OptionsDialog", "WebUI", nullptr));
        QListWidgetItem *___qlistwidgetitem8 = tabSelection->item(8);
        ___qlistwidgetitem8->setText(QCoreApplication::translate("OptionsDialog", "Advanced", nullptr));
        tabSelection->setSortingEnabled(__sortingEnabled);

        UISettingsBox->setTitle(QCoreApplication::translate("OptionsDialog", "Interface", nullptr));
        labelRestartRequired->setText(QCoreApplication::translate("OptionsDialog", "Changing Interface settings requires application restart", nullptr));
        labelLanguage->setText(QCoreApplication::translate("OptionsDialog", "Language:", nullptr));
        labelStyle->setText(QCoreApplication::translate("OptionsDialog", "Style:", nullptr));
        labelColorScheme->setText(QCoreApplication::translate("OptionsDialog", "Color scheme:", nullptr));
        checkUseCustomTheme->setTitle(QCoreApplication::translate("OptionsDialog", "Use custom UI Theme", nullptr));
        label_16->setText(QCoreApplication::translate("OptionsDialog", "UI Theme file:", nullptr));
        checkUseSystemIcon->setText(QCoreApplication::translate("OptionsDialog", "Use icons from system theme", nullptr));
        buttonCustomizeUITheme->setText(QCoreApplication::translate("OptionsDialog", "Customize UI Theme...", nullptr));
        groupBox_4->setTitle(QCoreApplication::translate("OptionsDialog", "Transfer List", nullptr));
#if QT_CONFIG(tooltip)
        confirmDeletion->setToolTip(QCoreApplication::translate("OptionsDialog", "Shows a confirmation dialog upon torrent deletion", nullptr));
#endif // QT_CONFIG(tooltip)
        confirmDeletion->setText(QCoreApplication::translate("OptionsDialog", "Confirm when deleting torrents", nullptr));
        checkAltRowColors->setText(QCoreApplication::translate("OptionsDialog", "Use alternating row colors", nullptr));
        checkUseTorrentStatesColors->setText(QCoreApplication::translate("OptionsDialog", "Use different text colors by torrent states", nullptr));
        checkProgressBarFollowsTextColor->setText(QCoreApplication::translate("OptionsDialog", "Make progress bars follow text colors", nullptr));
        checkHideZero->setText(QCoreApplication::translate("OptionsDialog", "Hide zero and infinity values", nullptr));
        comboHideZero->setItemText(0, QCoreApplication::translate("OptionsDialog", "Always", nullptr));
        comboHideZero->setItemText(1, QCoreApplication::translate("OptionsDialog", "Stopped torrents only", nullptr));

        groupBox_7->setTitle(QCoreApplication::translate("OptionsDialog", "Action on double-click", nullptr));
        lblDlList_2->setText(QCoreApplication::translate("OptionsDialog", "Downloading torrents:", nullptr));
        actionTorrentDlOnDblClBox->setItemText(0, QCoreApplication::translate("OptionsDialog", "Start / stop torrent", nullptr));
        actionTorrentDlOnDblClBox->setItemText(1, QCoreApplication::translate("OptionsDialog", "Open destination folder", nullptr));
        actionTorrentDlOnDblClBox->setItemText(2, QCoreApplication::translate("OptionsDialog", "Preview file, otherwise open destination folder", nullptr));
        actionTorrentDlOnDblClBox->setItemText(3, QCoreApplication::translate("OptionsDialog", "Open torrent options dialog", nullptr));
        actionTorrentDlOnDblClBox->setItemText(4, QCoreApplication::translate("OptionsDialog", "No action", nullptr));

        lblUploadList->setText(QCoreApplication::translate("OptionsDialog", "Completed torrents:", nullptr));
        actionTorrentFnOnDblClBox->setItemText(0, QCoreApplication::translate("OptionsDialog", "Start / stop torrent", nullptr));
        actionTorrentFnOnDblClBox->setItemText(1, QCoreApplication::translate("OptionsDialog", "Open destination folder", nullptr));
        actionTorrentFnOnDblClBox->setItemText(2, QCoreApplication::translate("OptionsDialog", "Preview file, otherwise open destination folder", nullptr));
        actionTorrentFnOnDblClBox->setItemText(3, QCoreApplication::translate("OptionsDialog", "Open torrent options dialog", nullptr));
        actionTorrentFnOnDblClBox->setItemText(4, QCoreApplication::translate("OptionsDialog", "No action", nullptr));

        checkBoxHideZeroStatusFilters->setText(QCoreApplication::translate("OptionsDialog", "Auto hide zero status filters", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxUseSeparateTrackerStatusFilter->setToolTip(QCoreApplication::translate("OptionsDialog", "Use separate \"Tracker status\" filter. Otherwise it gets merged with \"Trackers\" filter.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxUseSeparateTrackerStatusFilter->setText(QCoreApplication::translate("OptionsDialog", "Use separate \"Tracker status\" filter", nullptr));
        boxTorrentContent->setTitle(QCoreApplication::translate("OptionsDialog", "Torrent Content View", nullptr));
#if QT_CONFIG(tooltip)
        checkTorrentContentDrag->setToolTip(QCoreApplication::translate("OptionsDialog", "Replaces multi-selection (hold Alt key to invert)", nullptr));
#endif // QT_CONFIG(tooltip)
        checkTorrentContentDrag->setText(QCoreApplication::translate("OptionsDialog", "Drag content from qBittorrent", nullptr));
        systrayBox->setTitle(QCoreApplication::translate("OptionsDialog", "Desktop", nullptr));
        checkStartup->setText(QCoreApplication::translate("OptionsDialog", "Start qBittorrent on Windows start up", nullptr));
        checkShowSplash->setText(QCoreApplication::translate("OptionsDialog", "Show splash screen on start up", nullptr));
        windowStateLabel->setText(QCoreApplication::translate("OptionsDialog", "Window state on start up:", nullptr));
#if QT_CONFIG(tooltip)
        windowStateComboBox->setToolTip(QCoreApplication::translate("OptionsDialog", "qBittorrent window state on start up", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkProgramExitConfirm->setToolTip(QCoreApplication::translate("OptionsDialog", "Shows a confirmation dialog when exiting with active torrents", nullptr));
#endif // QT_CONFIG(tooltip)
        checkProgramExitConfirm->setText(QCoreApplication::translate("OptionsDialog", "Confirmation on exit when torrents are active", nullptr));
        checkProgramAutoExitConfirm->setText(QCoreApplication::translate("OptionsDialog", "Confirmation on auto-exit when downloads finish", nullptr));
        checkShowSystray->setTitle(QCoreApplication::translate("OptionsDialog", "Show &qBittorrent in notification area", nullptr));
#if QT_CONFIG(tooltip)
        checkMinimizeToSysTray->setToolTip(QCoreApplication::translate("OptionsDialog", "When minimizing, the main window is closed and must be reopened from the systray icon", nullptr));
#endif // QT_CONFIG(tooltip)
        checkMinimizeToSysTray->setText(QCoreApplication::translate("OptionsDialog", "Minimize qBittorrent to notification area", nullptr));
#if QT_CONFIG(tooltip)
        checkCloseToSystray->setToolTip(QCoreApplication::translate("OptionsDialog", "The systray icon will still be visible when closing the main window", nullptr));
#endif // QT_CONFIG(tooltip)
        checkCloseToSystray->setText(QCoreApplication::translate("OptionsDialog", "Close qBittorrent to notification area", nullptr));
        labelTrayIconStyle->setText(QCoreApplication::translate("OptionsDialog", "Tray icon style:", nullptr));
        comboTrayIcon->setItemText(0, QCoreApplication::translate("OptionsDialog", "Normal", nullptr));
        comboTrayIcon->setItemText(1, QCoreApplication::translate("OptionsDialog", "Monochrome (for dark theme)", nullptr));
        comboTrayIcon->setItemText(2, QCoreApplication::translate("OptionsDialog", "Monochrome (for light theme)", nullptr));

        groupFileAssociation->setTitle(QCoreApplication::translate("OptionsDialog", "File association", nullptr));
        checkAssociateTorrents->setText(QCoreApplication::translate("OptionsDialog", "Use qBittorrent for .torrent files", nullptr));
        checkAssociateMagnetLinks->setText(QCoreApplication::translate("OptionsDialog", "Use qBittorrent for magnet links", nullptr));
        labelSetAssoc->setText(QCoreApplication::translate("OptionsDialog", "<html><head/><body><p>To set qBittorrent as default program for .torrent files and/or Magnet links<br/>you can use <span style=\" font-weight:600;\">Default Programs</span> dialog from <span style=\" font-weight:600;\">Control Panel</span>.</p></body></html>", nullptr));
        checkProgramUpdates->setText(QCoreApplication::translate("OptionsDialog", "Check for program updates", nullptr));
        checkShowSpeedInDock->setText(QCoreApplication::translate("OptionsDialog", "Show speed in Dock", nullptr));
        checkShowMenuBarIcon->setText(QCoreApplication::translate("OptionsDialog", "Show qBittorrent in menu bar", nullptr));
        groupBox->setTitle(QCoreApplication::translate("OptionsDialog", "Power Management", nullptr));
        checkPreventFromSuspendWhenDownloading->setText(QCoreApplication::translate("OptionsDialog", "Inhibit system sleep when torrents are downloading", nullptr));
        checkPreventFromSuspendWhenSeeding->setText(QCoreApplication::translate("OptionsDialog", "Inhibit system sleep when torrents are seeding", nullptr));
        checkFileLog->setTitle(QCoreApplication::translate("OptionsDialog", "&Log Files", nullptr));
        label_4->setText(QCoreApplication::translate("OptionsDialog", "Save path:", nullptr));
#if QT_CONFIG(tooltip)
        checkFileLogBackup->setToolTip(QCoreApplication::translate("OptionsDialog", "Creates an additional log file after the log file reaches the specified file size", nullptr));
#endif // QT_CONFIG(tooltip)
        checkFileLogBackup->setText(QCoreApplication::translate("OptionsDialog", "Backup the log file after:", nullptr));
        spinFileLogSize->setSuffix(QCoreApplication::translate("OptionsDialog", " KiB", nullptr));
        checkFileLogDelete->setText(QCoreApplication::translate("OptionsDialog", "Delete backup logs older than:", nullptr));
        comboFileLogAgeType->setItemText(0, QCoreApplication::translate("OptionsDialog", "days", nullptr));
        comboFileLogAgeType->setItemText(1, QCoreApplication::translate("OptionsDialog", "months", nullptr));
        comboFileLogAgeType->setItemText(2, QCoreApplication::translate("OptionsDialog", "years", nullptr));

        checkBoxFreeDiskSpaceStatusBar->setText(QCoreApplication::translate("OptionsDialog", "Show free disk space in status bar", nullptr));
        checkBoxExternalIPStatusBar->setText(QCoreApplication::translate("OptionsDialog", "Show external IP in status bar", nullptr));
        checkBoxPerformanceWarning->setText(QCoreApplication::translate("OptionsDialog", "Log performance warnings", nullptr));
        torrentAdditionBox->setTitle(QCoreApplication::translate("OptionsDialog", "When adding a torrent", nullptr));
        checkAdditionDialog->setTitle(QCoreApplication::translate("OptionsDialog", "Display &torrent content and some options", nullptr));
        checkAdditionDialogFront->setText(QCoreApplication::translate("OptionsDialog", "Bring torrent dialog to the front", nullptr));
        contentLayoutLabel->setText(QCoreApplication::translate("OptionsDialog", "Torrent content layout:", nullptr));
        contentLayoutComboBox->setItemText(0, QCoreApplication::translate("OptionsDialog", "Original", nullptr));
        contentLayoutComboBox->setItemText(1, QCoreApplication::translate("OptionsDialog", "Create subfolder", nullptr));
        contentLayoutComboBox->setItemText(2, QCoreApplication::translate("OptionsDialog", "Don't create subfolder", nullptr));

#if QT_CONFIG(tooltip)
        checkAddToQueueTop->setToolTip(QCoreApplication::translate("OptionsDialog", "The torrent will be added to the top of the download queue", nullptr));
#endif // QT_CONFIG(tooltip)
        checkAddToQueueTop->setText(QCoreApplication::translate("OptionsDialog", "Add to top of queue", nullptr));
#if QT_CONFIG(tooltip)
        checkAddStopped->setToolTip(QCoreApplication::translate("OptionsDialog", "The torrent will be added to download list in a stopped state", nullptr));
#endif // QT_CONFIG(tooltip)
        checkAddStopped->setText(QCoreApplication::translate("OptionsDialog", "Do not start the download automatically", nullptr));
        stopConditionLabel->setText(QCoreApplication::translate("OptionsDialog", "Torrent stop condition:", nullptr));
        stopConditionComboBox->setItemText(0, QCoreApplication::translate("OptionsDialog", "None", nullptr));
        stopConditionComboBox->setItemText(1, QCoreApplication::translate("OptionsDialog", "Metadata received", nullptr));
        stopConditionComboBox->setItemText(2, QCoreApplication::translate("OptionsDialog", "Files checked", nullptr));

        duplicateTorrentGroup->setTitle(QCoreApplication::translate("OptionsDialog", "When adding a duplicate torrent", nullptr));
        checkMergeTrackers->setText(QCoreApplication::translate("OptionsDialog", "Merge trackers to existing torrent", nullptr));
        checkConfirmMergeTrackers->setText(QCoreApplication::translate("OptionsDialog", "Ask to merge trackers for manually added torrent", nullptr));
#if QT_CONFIG(tooltip)
        deleteTorrentBox->setToolTip(QCoreApplication::translate("OptionsDialog", "Whether the .torrent file should be deleted after adding it", nullptr));
#endif // QT_CONFIG(tooltip)
        deleteTorrentBox->setTitle(QCoreApplication::translate("OptionsDialog", "De&lete .torrent files afterwards ", nullptr));
#if QT_CONFIG(tooltip)
        deleteCancelledTorrentBox->setToolTip(QCoreApplication::translate("OptionsDialog", "Also delete .torrent files whose addition was cancelled", nullptr));
#endif // QT_CONFIG(tooltip)
        deleteCancelledTorrentBox->setText(QCoreApplication::translate("OptionsDialog", "Also when addition is cancelled", nullptr));
        deleteTorrentWarningLabel->setText(QCoreApplication::translate("OptionsDialog", "Warning! Data loss possible!", nullptr));
#if QT_CONFIG(tooltip)
        checkPreallocateAll->setToolTip(QCoreApplication::translate("OptionsDialog", "Allocate full file sizes on disk before starting downloads, to minimize fragmentation. Only useful for HDDs.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkPreallocateAll->setText(QCoreApplication::translate("OptionsDialog", "Pre-allocate disk space for all files", nullptr));
        checkAppendqB->setText(QCoreApplication::translate("OptionsDialog", "Append .!qB extension to incomplete files", nullptr));
        checkUnwantedFolder->setText(QCoreApplication::translate("OptionsDialog", "Keep unselected files in \".unwanted\" folder", nullptr));
#if QT_CONFIG(tooltip)
        checkRecursiveDownload->setToolTip(QCoreApplication::translate("OptionsDialog", "When a torrent is downloaded, offer to add torrents from any .torrent files found inside it", nullptr));
#endif // QT_CONFIG(tooltip)
        checkRecursiveDownload->setText(QCoreApplication::translate("OptionsDialog", "Enable recursive download dialog", nullptr));
        groupSavingManagement->setTitle(QCoreApplication::translate("OptionsDialog", "Saving Management", nullptr));
        label_40->setText(QCoreApplication::translate("OptionsDialog", "Default Torrent Management Mode:", nullptr));
        comboSavingMode->setItemText(0, QCoreApplication::translate("OptionsDialog", "Manual", nullptr));
        comboSavingMode->setItemText(1, QCoreApplication::translate("OptionsDialog", "Automatic", nullptr));

#if QT_CONFIG(tooltip)
        comboSavingMode->setToolTip(QCoreApplication::translate("OptionsDialog", "Automatic: Various torrent properties (e.g. save path) will be decided by the associated category\n"
"Manual: Various torrent properties (e.g. save path) must be assigned manually", nullptr));
#endif // QT_CONFIG(tooltip)
        labelTorrentCategoryChanged->setText(QCoreApplication::translate("OptionsDialog", "When Torrent Category changed:", nullptr));
        comboTorrentCategoryChanged->setItemText(0, QCoreApplication::translate("OptionsDialog", "Relocate torrent", nullptr));
        comboTorrentCategoryChanged->setItemText(1, QCoreApplication::translate("OptionsDialog", "Switch torrent to Manual Mode", nullptr));

        labelCategoryDefaultPathChanged->setText(QCoreApplication::translate("OptionsDialog", "When Default Save/Incomplete Path changed:", nullptr));
        comboCategoryDefaultPathChanged->setItemText(0, QCoreApplication::translate("OptionsDialog", "Relocate affected torrents", nullptr));
        comboCategoryDefaultPathChanged->setItemText(1, QCoreApplication::translate("OptionsDialog", "Switch affected torrents to Manual Mode", nullptr));

        labelCategoryChanged->setText(QCoreApplication::translate("OptionsDialog", "When Category Save Path changed:", nullptr));
        comboCategoryChanged->setItemText(0, QCoreApplication::translate("OptionsDialog", "Relocate affected torrents", nullptr));
        comboCategoryChanged->setItemText(1, QCoreApplication::translate("OptionsDialog", "Switch affected torrents to Manual Mode", nullptr));

#if QT_CONFIG(tooltip)
        checkUseCategoryPaths->setToolTip(QCoreApplication::translate("OptionsDialog", "Resolve relative Save Path against appropriate Category path instead of Default one", nullptr));
#endif // QT_CONFIG(tooltip)
        checkUseCategoryPaths->setText(QCoreApplication::translate("OptionsDialog", "Use Category paths in Manual Mode", nullptr));
        labelSavePath->setText(QCoreApplication::translate("OptionsDialog", "Default Save Path:", nullptr));
        checkUseDownloadPath->setText(QCoreApplication::translate("OptionsDialog", "Use another path for incomplete torrents:", nullptr));
        checkExportDir->setText(QCoreApplication::translate("OptionsDialog", "Copy .torrent files to:", nullptr));
        checkExportDirFin->setText(QCoreApplication::translate("OptionsDialog", "Copy .torrent files for finished downloads to:", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("OptionsDialog", "Automatically add torrents from:", nullptr));
        addWatchedFolderButton->setText(QCoreApplication::translate("OptionsDialog", "Add...", nullptr));
        editWatchedFolderButton->setText(QCoreApplication::translate("OptionsDialog", "Options..", nullptr));
        removeWatchedFolderButton->setText(QCoreApplication::translate("OptionsDialog", "Remove", nullptr));
        groupExcludedFileNames->setTitle(QCoreApplication::translate("OptionsDialog", "Excluded file names", nullptr));
#if QT_CONFIG(tooltip)
        textExcludedFileNames->setToolTip(QCoreApplication::translate("OptionsDialog", "Blacklist filtered file names from being downloaded from torrent(s).\n"
"Files matching any of the filters in this list will have their priority automatically set to \"Do not download\".\n"
"\n"
"Use newlines to separate multiple entries. Can use wildcards as outlined below.\n"
"*: matches zero or more of any characters.\n"
"?: matches any single character.\n"
"[...]: sets of characters can be represented in square brackets.\n"
"\n"
"Examples\n"
"*.exe: filter '.exe' file extension.\n"
"readme.txt: filter exact file name.\n"
"?.txt: filter 'a.txt', 'b.txt' but not 'aa.txt'.\n"
"readme[0-9].txt: filter 'readme1.txt', 'readme2.txt' but not 'readme10.txt'.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupMailNotification->setTitle(QCoreApplication::translate("OptionsDialog", "Email notification &upon download completion", nullptr));
#if QT_CONFIG(tooltip)
        label_25->setToolTip(QCoreApplication::translate("OptionsDialog", "Sender", nullptr));
#endif // QT_CONFIG(tooltip)
        label_25->setText(QCoreApplication::translate("OptionsDialog", "From:", "From sender"));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(QCoreApplication::translate("OptionsDialog", "Receiver", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("OptionsDialog", "To:", "To receiver"));
        label_3->setText(QCoreApplication::translate("OptionsDialog", "SMTP server:", nullptr));
        checkSmtpSSL->setText(QCoreApplication::translate("OptionsDialog", "This server requires a secure connection (SSL)", nullptr));
        groupMailNotifAuth->setTitle(QCoreApplication::translate("OptionsDialog", "Authentication", nullptr));
        label_7->setText(QCoreApplication::translate("OptionsDialog", "Username:", nullptr));
        label_8->setText(QCoreApplication::translate("OptionsDialog", "Password:", nullptr));
        sendTestEmail->setText(QCoreApplication::translate("OptionsDialog", "Send test email", nullptr));
        autoRunBox->setTitle(QCoreApplication::translate("OptionsDialog", "Run external program", nullptr));
        groupBoxRunOnAdded->setTitle(QCoreApplication::translate("OptionsDialog", "Run on torrent added:", nullptr));
        groupBoxRunOnFinished->setTitle(QCoreApplication::translate("OptionsDialog", "Run on torrent finished:", nullptr));
        autoRunConsole->setText(QCoreApplication::translate("OptionsDialog", "Show console window", nullptr));
        label_24->setText(QCoreApplication::translate("OptionsDialog", "Peer connection protocol:", nullptr));
        comboProtocol->setItemText(0, QCoreApplication::translate("OptionsDialog", "TCP and \316\274TP", nullptr));

        ListeningPortBox->setTitle(QCoreApplication::translate("OptionsDialog", "Listening Port", nullptr));
        lbl_ports->setText(QCoreApplication::translate("OptionsDialog", "Port used for incoming connections:", nullptr));
#if QT_CONFIG(tooltip)
        spinPort->setToolTip(QCoreApplication::translate("OptionsDialog", "Set to 0 to let your system pick an unused port", nullptr));
#endif // QT_CONFIG(tooltip)
        spinPort->setSpecialValueText(QCoreApplication::translate("OptionsDialog", "Any", nullptr));
        randomButton->setText(QCoreApplication::translate("OptionsDialog", "Random", nullptr));
        checkUPnP->setText(QCoreApplication::translate("OptionsDialog", "Use UPnP / NAT-PMP port forwarding from my router", nullptr));
        nbConnecBox->setTitle(QCoreApplication::translate("OptionsDialog", "Connections Limits", nullptr));
        checkMaxConnections->setText(QCoreApplication::translate("OptionsDialog", "Global maximum number of connections:", nullptr));
        checkMaxConnectionsPerTorrent->setText(QCoreApplication::translate("OptionsDialog", "Maximum number of connections per torrent:", nullptr));
        checkMaxUploads->setText(QCoreApplication::translate("OptionsDialog", "Global maximum number of upload slots:", nullptr));
        checkMaxUploadsPerTorrent->setText(QCoreApplication::translate("OptionsDialog", "Maximum number of upload slots per torrent:", nullptr));
        groupI2P->setTitle(QCoreApplication::translate("OptionsDialog", "I2P (experimental)", nullptr));
        labelI2PHost->setText(QCoreApplication::translate("OptionsDialog", "Host:", nullptr));
        labelI2PPort->setText(QCoreApplication::translate("OptionsDialog", "Port:", nullptr));
#if QT_CONFIG(tooltip)
        checkI2PMixed->setToolTip(QCoreApplication::translate("OptionsDialog", "<html><head/><body><p>If \"mixed mode\" is enabled I2P torrents are allowed to also get peers from other sources than the tracker, and connect to regular IPs, not providing any anonymization. This may be useful if the user is not interested in the anonymization of I2P, but still wants to be able to connect to I2P peers.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        checkI2PMixed->setText(QCoreApplication::translate("OptionsDialog", "Mixed mode", nullptr));
        groupProxy->setTitle(QCoreApplication::translate("OptionsDialog", "Proxy Server", nullptr));
        ProxyType_lbl->setText(QCoreApplication::translate("OptionsDialog", "Type:", nullptr));
        lblProxyIP->setText(QCoreApplication::translate("OptionsDialog", "Host:", nullptr));
        lblProxyPort->setText(QCoreApplication::translate("OptionsDialog", "Port:", nullptr));
        labelProxyTypeUnavailable->setText(QCoreApplication::translate("OptionsDialog", "Some functions are unavailable with the chosen proxy type!", nullptr));
#if QT_CONFIG(tooltip)
        checkProxyHostnameLookup->setToolTip(QCoreApplication::translate("OptionsDialog", "If checked, hostname lookups are done via the proxy", nullptr));
#endif // QT_CONFIG(tooltip)
        checkProxyHostnameLookup->setText(QCoreApplication::translate("OptionsDialog", "Perform hostname lookup via proxy", nullptr));
        checkProxyAuth->setTitle(QCoreApplication::translate("OptionsDialog", "A&uthentication", nullptr));
        lblProxyUsername->setText(QCoreApplication::translate("OptionsDialog", "Username:", nullptr));
        lblProxyPassword->setText(QCoreApplication::translate("OptionsDialog", "Password:", nullptr));
        label_23->setText(QCoreApplication::translate("OptionsDialog", "Note: The password is saved unencrypted", nullptr));
        checkProxyBitTorrent->setTitle(QCoreApplication::translate("OptionsDialog", "Use proxy for BitTorrent purposes", nullptr));
#if QT_CONFIG(tooltip)
        checkProxyPeerConnections->setToolTip(QCoreApplication::translate("OptionsDialog", "Otherwise, the proxy server is only used for tracker connections", nullptr));
#endif // QT_CONFIG(tooltip)
        checkProxyPeerConnections->setText(QCoreApplication::translate("OptionsDialog", "Use proxy for peer connections", nullptr));
#if QT_CONFIG(tooltip)
        checkProxyRSS->setToolTip(QCoreApplication::translate("OptionsDialog", "RSS feeds will use proxy", nullptr));
#endif // QT_CONFIG(tooltip)
        checkProxyRSS->setText(QCoreApplication::translate("OptionsDialog", "Use proxy for RSS purposes", nullptr));
#if QT_CONFIG(tooltip)
        checkProxyMisc->setToolTip(QCoreApplication::translate("OptionsDialog", "Search engine, software updates or anything else will use proxy", nullptr));
#endif // QT_CONFIG(tooltip)
        checkProxyMisc->setText(QCoreApplication::translate("OptionsDialog", "Use proxy for general purposes", nullptr));
        groupIPFilter->setTitle(QCoreApplication::translate("OptionsDialog", "IP Fi&ltering", nullptr));
        checkIPFilter->setText(QCoreApplication::translate("OptionsDialog", "Filter path (.dat, .p2p, .p2b):", nullptr));
#if QT_CONFIG(tooltip)
        IpFilterRefreshBtn->setToolTip(QCoreApplication::translate("OptionsDialog", "Reload the filter", nullptr));
#endif // QT_CONFIG(tooltip)
        banListButton->setText(QCoreApplication::translate("OptionsDialog", "Manually banned IP addresses...", nullptr));
        checkIpFilterTrackers->setText(QCoreApplication::translate("OptionsDialog", "Apply to trackers", nullptr));
        rateLimitBox->setTitle(QCoreApplication::translate("OptionsDialog", "Global Rate Limits", nullptr));
        label_10->setText(QCoreApplication::translate("OptionsDialog", "Upload:", nullptr));
        spinUploadLimit->setSpecialValueText(QCoreApplication::translate("OptionsDialog", "\342\210\236", nullptr));
        spinUploadLimit->setSuffix(QCoreApplication::translate("OptionsDialog", " KiB/s", nullptr));
        label_11->setText(QCoreApplication::translate("OptionsDialog", "Download:", nullptr));
        spinDownloadLimit->setSpecialValueText(QCoreApplication::translate("OptionsDialog", "\342\210\236", nullptr));
        spinDownloadLimit->setSuffix(QCoreApplication::translate("OptionsDialog", " KiB/s", nullptr));
        altRateLimitBox->setTitle(QCoreApplication::translate("OptionsDialog", "Alternative Rate Limits", nullptr));
        label_13->setText(QCoreApplication::translate("OptionsDialog", "Upload:", nullptr));
        spinUploadLimitAlt->setSpecialValueText(QCoreApplication::translate("OptionsDialog", "\342\210\236", nullptr));
        spinUploadLimitAlt->setSuffix(QCoreApplication::translate("OptionsDialog", " KiB/s", nullptr));
        label_14->setText(QCoreApplication::translate("OptionsDialog", "Download:", nullptr));
        spinDownloadLimitAlt->setSpecialValueText(QCoreApplication::translate("OptionsDialog", "\342\210\236", nullptr));
        spinDownloadLimitAlt->setSuffix(QCoreApplication::translate("OptionsDialog", " KiB/s", nullptr));
        groupBoxSchedule->setTitle(QCoreApplication::translate("OptionsDialog", "Schedule &the use of alternative rate limits", nullptr));
#if QT_CONFIG(tooltip)
        label_6->setToolTip(QCoreApplication::translate("OptionsDialog", "Start time", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(QCoreApplication::translate("OptionsDialog", "From:", "From start time"));
#if QT_CONFIG(tooltip)
        label_17->setToolTip(QCoreApplication::translate("OptionsDialog", "End time", nullptr));
#endif // QT_CONFIG(tooltip)
        label_17->setText(QCoreApplication::translate("OptionsDialog", "To:", "To end time"));
        label_18->setText(QCoreApplication::translate("OptionsDialog", "When:", nullptr));
        comboBoxScheduleDays->setItemText(0, QCoreApplication::translate("OptionsDialog", "Every day", nullptr));
        comboBoxScheduleDays->setItemText(1, QCoreApplication::translate("OptionsDialog", "Weekdays", nullptr));
        comboBoxScheduleDays->setItemText(2, QCoreApplication::translate("OptionsDialog", "Weekends", nullptr));

        rateLimitsGroupBox->setTitle(QCoreApplication::translate("OptionsDialog", "Rate Limits Settings", nullptr));
        checkLimituTPConnections->setText(QCoreApplication::translate("OptionsDialog", "Apply rate limit to \302\265TP protocol", nullptr));
        checkLimitTransportOverhead->setText(QCoreApplication::translate("OptionsDialog", "Apply rate limit to transport overhead", nullptr));
        checkLimitLocalPeerRate->setText(QCoreApplication::translate("OptionsDialog", "Apply rate limit to peers on LAN", nullptr));
        AddBTFeaturesBox->setTitle(QCoreApplication::translate("OptionsDialog", "Privacy", nullptr));
#if QT_CONFIG(tooltip)
        checkDHT->setToolTip(QCoreApplication::translate("OptionsDialog", "Find peers on the DHT network", nullptr));
#endif // QT_CONFIG(tooltip)
        checkDHT->setText(QCoreApplication::translate("OptionsDialog", "Enable DHT (decentralized network) to find more peers", nullptr));
#if QT_CONFIG(tooltip)
        checkPeX->setToolTip(QCoreApplication::translate("OptionsDialog", "Exchange peers with compatible Bittorrent clients (\302\265Torrent, Vuze, ...)", nullptr));
#endif // QT_CONFIG(tooltip)
        checkPeX->setText(QCoreApplication::translate("OptionsDialog", "Enable Peer Exchange (PeX) to find more peers", nullptr));
#if QT_CONFIG(tooltip)
        checkLSD->setToolTip(QCoreApplication::translate("OptionsDialog", "Look for peers on your local network", nullptr));
#endif // QT_CONFIG(tooltip)
        checkLSD->setText(QCoreApplication::translate("OptionsDialog", "Enable Local Peer Discovery to find more peers", nullptr));
        lbl_encryption->setText(QCoreApplication::translate("OptionsDialog", "Encryption mode:", nullptr));
        comboEncryption->setItemText(0, QCoreApplication::translate("OptionsDialog", "Allow encryption", nullptr));
        comboEncryption->setItemText(1, QCoreApplication::translate("OptionsDialog", "Require encryption", nullptr));
        comboEncryption->setItemText(2, QCoreApplication::translate("OptionsDialog", "Disable encryption", nullptr));

#if QT_CONFIG(tooltip)
        comboEncryption->setToolTip(QCoreApplication::translate("OptionsDialog", "Allow encryption: Connect to peers regardless of setting\n"
"Require encryption: Only connect to peers with protocol encryption\n"
"Disable encryption: Only connect to peers without protocol encryption", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkAnonymousMode->setToolTip(QCoreApplication::translate("OptionsDialog", "Enable when using a proxy or a VPN connection", nullptr));
#endif // QT_CONFIG(tooltip)
        checkAnonymousMode->setText(QCoreApplication::translate("OptionsDialog", "Enable anonymous mode", nullptr));
        label_anonymous->setText(QCoreApplication::translate("OptionsDialog", "(<a href=\"https://github.com/qbittorrent/qBittorrent/wiki/Anonymous-Mode\">More information</a>)", nullptr));
        labelMaxActiveCheckingTorrents->setText(QCoreApplication::translate("OptionsDialog", "Maximum active checking torrents:", nullptr));
        checkEnableQueueing->setTitle(QCoreApplication::translate("OptionsDialog", "&Torrent Queueing", nullptr));
        label_max_active_dl->setText(QCoreApplication::translate("OptionsDialog", "Maximum active downloads:", nullptr));
        spinMaxActiveDownloads->setSpecialValueText(QCoreApplication::translate("OptionsDialog", "\342\210\236", nullptr));
        label_max_active_up->setText(QCoreApplication::translate("OptionsDialog", "Maximum active uploads:", nullptr));
        spinMaxActiveUploads->setSpecialValueText(QCoreApplication::translate("OptionsDialog", "\342\210\236", nullptr));
        maxActiveTorrents_lbl->setText(QCoreApplication::translate("OptionsDialog", "Maximum active torrents:", nullptr));
        spinMaxActiveTorrents->setSpecialValueText(QCoreApplication::translate("OptionsDialog", "\342\210\236", nullptr));
        checkIgnoreSlowTorrentsForQueueing->setTitle(QCoreApplication::translate("OptionsDialog", "Do not count slow torrents in these limits", nullptr));
        labelDownloadRateForSlowTorrents->setText(QCoreApplication::translate("OptionsDialog", "Download rate threshold:", nullptr));
        spinDownloadRateForSlowTorrents->setSuffix(QCoreApplication::translate("OptionsDialog", " KiB/s", nullptr));
        labelUploadRateForSlowTorrents->setText(QCoreApplication::translate("OptionsDialog", "Upload rate threshold:", nullptr));
        spinUploadRateForSlowTorrents->setSuffix(QCoreApplication::translate("OptionsDialog", " KiB/s", nullptr));
        labelSlowTorrentInactivityTimer->setText(QCoreApplication::translate("OptionsDialog", "Torrent inactivity timer:", nullptr));
        spinSlowTorrentsInactivityTimer->setSuffix(QCoreApplication::translate("OptionsDialog", " sec", nullptr));
        seedingLimitsBox->setTitle(QCoreApplication::translate("OptionsDialog", "Seeding Limits", nullptr));
        checkMaxRatio->setText(QCoreApplication::translate("OptionsDialog", "When ratio reaches", nullptr));
        checkMaxSeedingMinutes->setText(QCoreApplication::translate("OptionsDialog", "When total seeding time reaches", nullptr));
        spinMaxSeedingMinutes->setSuffix(QCoreApplication::translate("OptionsDialog", " min", nullptr));
        checkMaxInactiveSeedingMinutes->setText(QCoreApplication::translate("OptionsDialog", "When inactive seeding time reaches", nullptr));
        spinMaxInactiveSeedingMinutes->setSuffix(QCoreApplication::translate("OptionsDialog", " min", nullptr));
        label->setText(QCoreApplication::translate("OptionsDialog", "then", nullptr));
        comboRatioLimitAct->setItemText(0, QCoreApplication::translate("OptionsDialog", "Stop torrent", nullptr));
        comboRatioLimitAct->setItemText(1, QCoreApplication::translate("OptionsDialog", "Remove torrent", nullptr));
        comboRatioLimitAct->setItemText(2, QCoreApplication::translate("OptionsDialog", "Remove torrent and its files", nullptr));
        comboRatioLimitAct->setItemText(3, QCoreApplication::translate("OptionsDialog", "Enable super seeding for torrent", nullptr));

        checkEnableAddTrackers->setTitle(QCoreApplication::translate("OptionsDialog", "A&utomatically append these trackers to new downloads:", nullptr));
        checkAddTrackersFromURL->setTitle(QCoreApplication::translate("OptionsDialog", "Automatically append trackers from URL to new downloads:", nullptr));
        labelCustomizeTrackersListUrl->setText(QCoreApplication::translate("OptionsDialog", "URL:", nullptr));
        labeltrackersFromURL->setText(QCoreApplication::translate("OptionsDialog", "Fetched trackers", nullptr));
        groupSearchUI->setTitle(QCoreApplication::translate("OptionsDialog", "Search UI", nullptr));
        groupStoreOpenedTabs->setTitle(QCoreApplication::translate("OptionsDialog", "Store opened tabs", nullptr));
        checkStoreTabsSearchResults->setText(QCoreApplication::translate("OptionsDialog", "Also store search results", nullptr));
        searchHistoryLengthLabel->setText(QCoreApplication::translate("OptionsDialog", "History length", nullptr));
        groupRSSReader->setTitle(QCoreApplication::translate("OptionsDialog", "RSS Reader", nullptr));
        checkRSSEnable->setText(QCoreApplication::translate("OptionsDialog", "Enable fetching RSS feeds", nullptr));
        label_111->setText(QCoreApplication::translate("OptionsDialog", "Feeds refresh interval:", nullptr));
        spinRSSRefreshInterval->setSuffix(QCoreApplication::translate("OptionsDialog", " min", nullptr));
        labelRSSFetchDelay->setText(QCoreApplication::translate("OptionsDialog", "Same host request delay:", nullptr));
        spinRSSFetchDelay->setSuffix(QCoreApplication::translate("OptionsDialog", " sec", nullptr));
        label_12->setText(QCoreApplication::translate("OptionsDialog", "Maximum number of articles per feed:", nullptr));
        groupRSSAutoDownloader->setTitle(QCoreApplication::translate("OptionsDialog", "RSS Torrent Auto Downloader", nullptr));
        checkRSSAutoDownloaderEnable->setText(QCoreApplication::translate("OptionsDialog", "Enable auto downloading of RSS torrents", nullptr));
        btnEditRules->setText(QCoreApplication::translate("OptionsDialog", "Edit auto downloading rules...", nullptr));
        groupRSSSmartEpisodeFilter->setTitle(QCoreApplication::translate("OptionsDialog", "RSS Smart Episode Filter", nullptr));
        checkSmartFilterDownloadRepacks->setText(QCoreApplication::translate("OptionsDialog", "Download REPACK/PROPER episodes", nullptr));
        label_5->setText(QCoreApplication::translate("OptionsDialog", "Filters:", nullptr));
        checkWebUI->setTitle(QCoreApplication::translate("OptionsDialog", "Web User Interface (Remote control)", nullptr));
        labelWebUIError->setText(QString());
        lblWebUIAddress->setText(QCoreApplication::translate("OptionsDialog", "IP address:", nullptr));
#if QT_CONFIG(tooltip)
        textWebUIAddress->setToolTip(QCoreApplication::translate("OptionsDialog", "IP address that the Web UI will bind to.\n"
"Specify an IPv4 or IPv6 address. You can specify \"0.0.0.0\" for any IPv4 address,\n"
"\"::\" for any IPv6 address, or \"*\" for both IPv4 and IPv6.", nullptr));
#endif // QT_CONFIG(tooltip)
        lblWebUIPort->setText(QCoreApplication::translate("OptionsDialog", "Port:", nullptr));
        checkWebUIUPnP->setText(QCoreApplication::translate("OptionsDialog", "Use UPnP / NAT-PMP to forward the port from my router", nullptr));
        checkWebUIHttps->setTitle(QCoreApplication::translate("OptionsDialog", "&Use HTTPS instead of HTTP", nullptr));
        lblWebUICrt->setText(QCoreApplication::translate("OptionsDialog", "Certificate:", nullptr));
        lblWebUIKey->setText(QCoreApplication::translate("OptionsDialog", "Key:", nullptr));
        lblWebUICertInfo->setText(QCoreApplication::translate("OptionsDialog", "<a href=https://httpd.apache.org/docs/current/ssl/ssl_faq.html#aboutcerts>Information about certificates</a>", nullptr));
        groupWebUIAuth->setTitle(QCoreApplication::translate("OptionsDialog", "Authentication", nullptr));
        groupWebUIUser->setTitle(QCoreApplication::translate("OptionsDialog", "User", nullptr));
        lblWebUIUsername->setText(QCoreApplication::translate("OptionsDialog", "Username:", nullptr));
        lblWebUIPassword->setText(QCoreApplication::translate("OptionsDialog", "Password:", nullptr));
        textWebUIPassword->setPlaceholderText(QCoreApplication::translate("OptionsDialog", "Change current password", nullptr));
        groupWebUIAPIKey->setTitle(QCoreApplication::translate("OptionsDialog", "API Key", nullptr));
        lblWebUIAPIKey->setText(QCoreApplication::translate("OptionsDialog", "Key:", nullptr));
        textWebUIAPIKey->setPlaceholderText(QCoreApplication::translate("OptionsDialog", "Generate a key", nullptr));
#if QT_CONFIG(tooltip)
        btnWebUIAPIKeyCopy->setToolTip(QCoreApplication::translate("OptionsDialog", "Copy API key", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        btnWebUIAPIKeyRotate->setToolTip(QCoreApplication::translate("OptionsDialog", "Generate API key", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        btnWebUIAPIKeyDelete->setToolTip(QCoreApplication::translate("OptionsDialog", "Delete API key", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBypassLocalAuth->setText(QCoreApplication::translate("OptionsDialog", "Bypass authentication for clients on localhost", nullptr));
        checkBypassAuthSubnetWhitelist->setText(QCoreApplication::translate("OptionsDialog", "Bypass authentication for clients in whitelisted IP subnets", nullptr));
        IPSubnetWhitelistButton->setText(QCoreApplication::translate("OptionsDialog", "IP subnet whitelist...", nullptr));
        lblBanCounter->setText(QCoreApplication::translate("OptionsDialog", "Ban client after consecutive failures:", nullptr));
        spinBanCounter->setSpecialValueText(QCoreApplication::translate("OptionsDialog", "Never", nullptr));
        lblBanDuration->setText(QCoreApplication::translate("OptionsDialog", "ban for:", nullptr));
        spinBanDuration->setSuffix(QCoreApplication::translate("OptionsDialog", " sec", nullptr));
        lblSessionTimeout->setText(QCoreApplication::translate("OptionsDialog", "Session timeout:", nullptr));
        spinSessionTimeout->setSpecialValueText(QCoreApplication::translate("OptionsDialog", "Disabled", nullptr));
        spinSessionTimeout->setSuffix(QCoreApplication::translate("OptionsDialog", " sec", nullptr));
        groupAltWebUI->setTitle(QCoreApplication::translate("OptionsDialog", "Use alternative WebUI", nullptr));
        labelWebUIRootFolder->setText(QCoreApplication::translate("OptionsDialog", "Files location:", nullptr));
        lblAltWebUIList->setText(QCoreApplication::translate("OptionsDialog", "<a href=\"https://github.com/qbittorrent/qBittorrent/wiki/List-of-known-alternate-WebUIs\">List of alternative WebUI</a>", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("OptionsDialog", "Security", nullptr));
        checkClickjacking->setText(QCoreApplication::translate("OptionsDialog", "Enable clickjacking protection", nullptr));
        checkCSRFProtection->setText(QCoreApplication::translate("OptionsDialog", "Enable Cross-Site Request Forgery (CSRF) protection", nullptr));
        checkSecureCookie->setText(QCoreApplication::translate("OptionsDialog", "Enable cookie Secure flag (requires HTTPS or localhost connection)", nullptr));
        groupHostHeaderValidation->setTitle(QCoreApplication::translate("OptionsDialog", "Enable Host header validation", nullptr));
        labelServerDomains->setText(QCoreApplication::translate("OptionsDialog", "Server domains:", nullptr));
#if QT_CONFIG(tooltip)
        textServerDomains->setToolTip(QCoreApplication::translate("OptionsDialog", "Whitelist for filtering HTTP Host header values.\n"
"In order to defend against DNS rebinding attack,\n"
"you should put in domain names used by WebUI server.\n"
"\n"
"Use ';' to split multiple entries. Can use wildcard '*'.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupWebUIAddCustomHTTPHeaders->setTitle(QCoreApplication::translate("OptionsDialog", "Add custom HTTP headers", nullptr));
        textWebUICustomHTTPHeaders->setPlaceholderText(QCoreApplication::translate("OptionsDialog", "Header: value pairs, one per line", nullptr));
        groupEnableReverseProxySupport->setTitle(QCoreApplication::translate("OptionsDialog", "Enable reverse proxy support", nullptr));
        lblReverseProxiesList->setText(QCoreApplication::translate("OptionsDialog", "Trusted proxies list:", nullptr));
#if QT_CONFIG(tooltip)
        textTrustedReverseProxiesList->setToolTip(QCoreApplication::translate("OptionsDialog", "Specify reverse proxy IPs (or subnets, e.g. 0.0.0.0/24) in order to use forwarded client address (X-Forwarded-For header). Use ';' to split multiple entries.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelReverseProxyLink->setText(QCoreApplication::translate("OptionsDialog", "<a href=https://github.com/qbittorrent/qBittorrent/wiki#reverse-proxy-setup-for-webui-access>Reverse proxy setup examples</a>", nullptr));
        checkDynDNS->setTitle(QCoreApplication::translate("OptionsDialog", "Upda&te my dynamic domain name", nullptr));
        label_19->setText(QCoreApplication::translate("OptionsDialog", "Service:", nullptr));

        registerDNSBtn->setText(QCoreApplication::translate("OptionsDialog", "Register", nullptr));
        label_20->setText(QCoreApplication::translate("OptionsDialog", "Domain name:", nullptr));
        label_21->setText(QCoreApplication::translate("OptionsDialog", "Username:", nullptr));
        label_22->setText(QCoreApplication::translate("OptionsDialog", "Password:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OptionsDialog: public Ui_OptionsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONSDIALOG_H
